@@ -28,14 +28,13 @@
 #include <AkonadiCore/Collection>
 #include <AkonadiCore/EntityDisplayAttribute>
 #include <AkonadiCore/Item>
-#include <Akonadi/Notes/NoteUtils>
 #include <KCalCore/Todo>
+#if __has_include(<kcalcore_version.h>)
 #include <kcalcore_version.h>
-#include <KMime/Message>
-#include <QMimeDatabase>
-#if KCALCORE_VERSION < QT_VERSION_CHECK(5, 6, 80)
-#include <KDateTime>
+#else
+#include <kcalendarcore_version.h>
 #endif
+#include <QMimeDatabase>
 
 #include <numeric>
 
@@ -64,19 +63,9 @@ bool Serializer::representsItem(QObjectPtr object, Item item)
     return object->property("itemId").toLongLong() == item.id();
 }
 
-bool Serializer::representsAkonadiTag(Domain::Tag::Ptr tag, Tag akonadiTag) const
-{
-    return tag->property("tagId").toLongLong() == akonadiTag.id();
-}
-
-QString Serializer::objectUid(SerializerInterface::QObjectPtr object)
-{
-    return object->property("todoUid").toString();
-}
-
 QString Serializer::itemUid(const Item &item)
 {
-    if (isTaskItem(item)) {
+    if (item.hasPayload<KCalCore::Todo::Ptr>()) {
         const auto todo = item.payload<KCalCore::Todo::Ptr>();
         return todo->uid();
     } else {
@@ -113,8 +102,6 @@ void Serializer::updateDataSourceFromCollection(Domain::DataSource::Ptr dataSour
 
     const auto mimeTypes = collection.contentMimeTypes();
     auto types = Domain::DataSource::ContentTypes();
-    if (mimeTypes.contains(NoteUtils::noteMimeType()))
-        types |= Domain::DataSource::Notes;
     if (mimeTypes.contains(KCalCore::Todo::todoMimeType()))
         types |= Domain::DataSource::Tasks;
     dataSource->setContentTypes(types);
@@ -149,7 +136,7 @@ Collection Serializer::createCollectionFromDataSource(Domain::DataSource::Ptr da
 
 bool Serializer::isSelectedCollection(Collection collection)
 {
-    if (!isNoteCollection(collection) && !isTaskCollection(collection))
+    if (!isTaskCollection(collection))
         return false;
 
     if (!collection.hasAttribute<Akonadi::ApplicationSelectedAttribute>())
@@ -158,11 +145,6 @@ bool Serializer::isSelectedCollection(Collection collection)
     return collection.attribute<Akonadi::ApplicationSelectedAttribute>()->isSelected();
 }
 
-bool Akonadi::Serializer::isNoteCollection(Akonadi::Collection collection)
-{
-    return collection.contentMimeTypes().contains(NoteUtils::noteMimeType());
-}
-
 bool Akonadi::Serializer::isTaskCollection(Akonadi::Collection collection)
 {
     return collection.contentMimeTypes().contains(KCalCore::Todo::todoMimeType());
@@ -173,8 +155,7 @@ bool Serializer::isTaskItem(Item item)
     if (!item.hasPayload<KCalCore::Todo::Ptr>())
         return false;
 
-    auto todo = item.payload<KCalCore::Todo::Ptr>();
-    return todo->customProperty("Zanshin", "Project").isEmpty();
+    return !isProjectItem(item) && !isContext(item);
 }
 
 Domain::Task::Ptr Serializer::createTaskFromItem(Item item)
@@ -197,26 +178,17 @@ void Serializer::updateTaskFromItem(Domain::Task::Ptr task, Item item)
     task->setTitle(todo->summary());
     task->setText(todo->description());
     task->setDone(todo->isCompleted());
-#if KCALCORE_VERSION >= QT_VERSION_CHECK(5, 6, 80)
-    if (todo->allDay()) {
-        task->setDoneDate(QDateTime(todo->completed().date(), QTime(), Qt::UTC));
-        task->setStartDate(QDateTime(todo->dtStart().date(), QTime(), Qt::UTC));
-        task->setDueDate(QDateTime(todo->dtDue().date(), QTime(), Qt::UTC));
-    } else {
-        task->setDoneDate(todo->completed().toUTC());
-        task->setStartDate(todo->dtStart().toUTC());
-        task->setDueDate(todo->dtDue().toUTC());
-    }
-#else
-    task->setDoneDate(todo->completed().dateTime().toUTC());
-    task->setStartDate(todo->dtStart().dateTime().toUTC());
-    task->setDueDate(todo->dtDue().dateTime().toUTC());
-#endif
+    task->setDoneDate(todo->completed().toLocalTime().date());
+    task->setStartDate(todo->dtStart().toLocalTime().date());
+    task->setDueDate(todo->dtDue().toLocalTime().date());
     task->setProperty("itemId", item.id());
     task->setProperty("parentCollectionId", item.parentCollection().id());
     task->setProperty("todoUid", todo->uid());
     task->setProperty("relatedUid", todo->relatedTo());
-    task->setRunning(todo->customProperty("Zanshin", "Running") == QLatin1String("1"));
+    task->setRunning(todo->customProperty(Serializer::customPropertyAppName(), Serializer::customPropertyIsRunning()) == QLatin1String("1"));
+    const auto contextUids = todo->customProperty(Serializer::customPropertyAppName(),
+                                                  Serializer::customPropertyContextList()).split(',', QString::SkipEmptyParts);
+    task->setProperty("contextUids", contextUids);
 
     switch (todo->recurrence()->recurrenceType()) {
     case KCalCore::Recurrence::rDaily:
@@ -228,6 +200,9 @@ void Serializer::updateTaskFromItem(Domain::Task::Ptr task, Item item)
     case KCalCore::Recurrence::rMonthlyDay:
         task->setRecurrence(Domain::Task::RecursMonthly);
         break;
+    case KCalCore::Recurrence::rYearlyMonth:
+        task->setRecurrence(Domain::Task::RecursYearly);
+        break;
     default:
         // Other cases are not supported for now and as such just ignored
         break;
@@ -239,6 +214,19 @@ void Serializer::updateTaskFromItem(Domain::Task::Ptr task, Item item)
     attachments.reserve(attachmentsInput.size());
     std::transform(attachmentsInput.cbegin(), attachmentsInput.cend(),
                    std::back_inserter(attachments),
+#if KCALCORE_VERSION >= QT_VERSION_CHECK(5, 11, 80)
+                   [&mimeDb] (const KCalCore::Attachment &attach) {
+                       Domain::Task::Attachment attachment;
+                       if (attach.isUri())
+                           attachment.setUri(QUrl(attach.uri()));
+                       else
+                           attachment.setData(attach.decodedData());
+                       attachment.setLabel(attach.label());
+                       attachment.setMimeType(attach.mimeType());
+                       attachment.setIconName(mimeDb.mimeTypeForName(attach.mimeType()).iconName());
+                       return attachment;
+                   });
+#else
                    [&mimeDb] (const KCalCore::Attachment::Ptr &attach) {
                        Domain::Task::Attachment attachment;
                        if (attach->isUri())
@@ -250,18 +238,8 @@ void Serializer::updateTaskFromItem(Domain::Task::Ptr task, Item item)
                        attachment.setIconName(mimeDb.mimeTypeForName(attach->mimeType()).iconName());
                        return attachment;
                    });
+#endif
     task->setAttachments(attachments);
-
-    if (todo->attendeeCount() > 0) {
-        const auto attendees = todo->attendees();
-        const auto delegate = std::find_if(attendees.begin(), attendees.end(),
-                                           [] (const KCalCore::Attendee::Ptr &attendee) {
-                                               return attendee->status() == KCalCore::Attendee::Accepted;
-                                           });
-        if (delegate != attendees.end()) {
-            task->setDelegate(Domain::Task::Delegate((*delegate)->name(), (*delegate)->email()));
-        }
-    }
 }
 
 bool Serializer::isTaskChild(Domain::Task::Ptr task, Akonadi::Item item)
@@ -276,11 +254,6 @@ bool Serializer::isTaskChild(Domain::Task::Ptr task, Akonadi::Item item)
     return false;
 }
 
-#if KCALCORE_VERSION >= QT_VERSION_CHECK(5, 6, 80)
-#define KDateTime QDateTime
-#endif
-
-
 Akonadi::Item Serializer::createItemFromTask(Domain::Task::Ptr task)
 {
     auto todo = KCalCore::Todo::Ptr::create();
@@ -290,16 +263,11 @@ Akonadi::Item Serializer::createItemFromTask(Domain::Task::Ptr task)
 
     // We only support all-day todos, so ignore timezone information and possible effect from timezone on dates
     // KCalCore reads "DUE;VALUE=DATE:20171130" as QDateTime(QDate(2017, 11, 30), QTime(), Qt::LocalTime), for lack of timezone information
-    // so we should never call toUtc() on that, it would mess up the date. Instead we force UTC while preserving the date.
+    // so we should never call toUtc() on that, it would mess up the date.
     // If one day we want to support time information, we need to add a task->isAllDay()/setAllDay().
-#if KCALCORE_VERSION >= QT_VERSION_CHECK(5, 6, 80)
-    todo->setDtStart(QDateTime(task->startDate().date(), QTime(), Qt::UTC));
-    todo->setDtDue(QDateTime(task->dueDate().date(), QTime(), Qt::UTC));
+    todo->setDtStart(QDateTime(task->startDate()));
+    todo->setDtDue(QDateTime(task->dueDate()));
     todo->setAllDay(true);
-#else
-    todo->setDtStart(KDateTime(task->startDate(), KDateTime::UTC));
-    todo->setDtDue(KDateTime(task->dueDate(), KDateTime::UTC));
-#endif
 
     if (task->property("todoUid").isValid()) {
         todo->setUid(task->property("todoUid").toString());
@@ -309,6 +277,12 @@ Akonadi::Item Serializer::createItemFromTask(Domain::Task::Ptr task)
         todo->setRelatedTo(task->property("relatedUid").toString());
     }
 
+    if (task->property("contextUids").isValid()) {
+        todo->setCustomProperty(customPropertyAppName(),
+                                customPropertyContextList(),
+                                task->property("contextUids").toStringList().join(','));
+    }
+
     switch (task->recurrence()) {
     case Domain::Task::NoRecurrence:
         break;
@@ -321,9 +295,21 @@ Akonadi::Item Serializer::createItemFromTask(Domain::Task::Ptr task)
     case Domain::Task::RecursMonthly:
         todo->recurrence()->setMonthly(1);
         break;
+    case Domain::Task::RecursYearly:
+        todo->recurrence()->setYearly(1);
+        break;
     }
 
     for (const auto &attachment : task->attachments()) {
+#if KCALCORE_VERSION >= QT_VERSION_CHECK(5, 11, 80)
+        KCalCore::Attachment attach(QByteArray{});
+        if (attachment.isUri())
+            attach.setUri(attachment.uri().toString());
+        else
+            attach.setDecodedData(attachment.data());
+        attach.setMimeType(attachment.mimeType());
+        attach.setLabel(attachment.label());
+#else
         KCalCore::Attachment::Ptr attach(new KCalCore::Attachment(QByteArray()));
         if (attachment.isUri())
             attach->setUri(attachment.uri().toString());
@@ -331,26 +317,20 @@ Akonadi::Item Serializer::createItemFromTask(Domain::Task::Ptr task)
             attach->setDecodedData(attachment.data());
         attach->setMimeType(attachment.mimeType());
         attach->setLabel(attachment.label());
+#endif
         todo->addAttachment(attach);
     }
 
-    if (task->delegate().isValid()) {
-        KCalCore::Attendee::Ptr attendee(new KCalCore::Attendee(task->delegate().name(),
-                                                                task->delegate().email(),
-                                                                true,
-                                                                KCalCore::Attendee::Accepted));
-        todo->addAttendee(attendee);
-    }
     if (task->isRunning()) {
-        todo->setCustomProperty("Zanshin", "Running", "1");
+        todo->setCustomProperty(Serializer::customPropertyAppName(), Serializer::customPropertyIsRunning(), "1");
     } else {
-        todo->removeCustomProperty("Zanshin", "Running");
+        todo->removeCustomProperty(Serializer::customPropertyAppName(), Serializer::customPropertyIsRunning());
     }
 
     // Needs to be done after all other dates are positioned
     // since this applies the recurrence logic
     if (task->isDone())
-        todo->setCompleted(KDateTime(task->doneDate()));
+        todo->setCompleted(QDateTime(task->doneDate(), QTime(), Qt::UTC));
     else
         todo->setCompleted(false);
 
@@ -372,12 +352,6 @@ QString Serializer::relatedUidFromItem(Akonadi::Item item)
     if (isTaskItem(item)) {
         const auto todo = item.payload<KCalCore::Todo::Ptr>();
         return todo->relatedTo();
-
-    } else if (isNoteItem(item)) {
-        const auto message = item.payload<KMime::Message::Ptr>();
-        const auto relatedHeader = message->headerByType("X-Zanshin-RelatedProjectUid");
-        return relatedHeader ? relatedHeader->asUnicodeString() : QString();
-
     } else {
         return QString();
     }
@@ -397,17 +371,6 @@ void Serializer::updateItemProject(Item item, Domain::Project::Ptr project)
     if (isTaskItem(item)) {
         auto todo = item.payload<KCalCore::Todo::Ptr>();
         todo->setRelatedTo(project->property("todoUid").toString());
-
-    } else if (isNoteItem(item)) {
-        auto note = item.payload<KMime::Message::Ptr>();
-        note->removeHeader("X-Zanshin-RelatedProjectUid");
-        const QByteArray parentUid = project->property("todoUid").toString().toUtf8();
-        if (!parentUid.isEmpty()) {
-            auto relatedHeader = new KMime::Headers::Generic("X-Zanshin-RelatedProjectUid");
-            relatedHeader->from7BitString(parentUid);
-            note->appendHeader(relatedHeader);
-        }
-        note->assemble();
     }
 }
 
@@ -427,7 +390,7 @@ void Serializer::promoteItemToProject(Akonadi::Item item)
 
     auto todo = item.payload<KCalCore::Todo::Ptr>();
     todo->setRelatedTo(QString());
-    todo->setCustomProperty("Zanshin", "Project", QStringLiteral("1"));
+    todo->setCustomProperty(Serializer::customPropertyAppName(), Serializer::customPropertyIsProject(), QStringLiteral("1"));
 }
 
 void Serializer::clearItem(Akonadi::Item *item)
@@ -436,11 +399,8 @@ void Serializer::clearItem(Akonadi::Item *item)
     if (!isTaskItem(*item))
         return;
 
-//    NOTE : Currently not working, when akonadistorage test will make it pass, we will use it
-//    item->clearTags();
-
-    foreach (const Tag& tag, item->tags())
-        item->clearTag(tag);
+    auto todo = item->payload<KCalCore::Todo::Ptr>();
+    todo->removeCustomProperty(Serializer::customPropertyAppName(), Serializer::customPropertyContextList());
 }
 
 Akonadi::Item::List Serializer::filterDescendantItems(const Akonadi::Item::List &potentialChildren, const Akonadi::Item &ancestorItem)
@@ -473,69 +433,13 @@ Akonadi::Item::List Serializer::filterDescendantItems(const Akonadi::Item::List
     return result;
 }
 
-bool Serializer::isNoteItem(Item item)
-{
-    return item.hasPayload<KMime::Message::Ptr>();
-}
-
-Domain::Note::Ptr Serializer::createNoteFromItem(Akonadi::Item item)
-{
-    if (!isNoteItem(item))
-        return Domain::Note::Ptr();
-
-    Domain::Note::Ptr note = Domain::Note::Ptr::create();
-    updateNoteFromItem(note, item);
-
-    return note;
-}
-
-void Serializer::updateNoteFromItem(Domain::Note::Ptr note, Item item)
-{
-    if (!isNoteItem(item))
-        return;
-
-    auto message = item.payload<KMime::Message::Ptr>();
-
-    note->setTitle(message->subject(true)->asUnicodeString());
-    note->setText(message->mainBodyPart()->decodedText());
-    note->setProperty("itemId", item.id());
-
-    if (auto relatedHeader = message->headerByType("X-Zanshin-RelatedProjectUid")) {
-        note->setProperty("relatedUid", relatedHeader->asUnicodeString());
-    } else {
-        note->setProperty("relatedUid", QVariant());
-    }
-}
-
-Item Serializer::createItemFromNote(Domain::Note::Ptr note)
-{
-    NoteUtils::NoteMessageWrapper builder;
-    builder.setTitle(note->title());
-    builder.setText(note->text() + '\n'); // Adding an extra '\n' because KMime always removes it...
-
-    KMime::Message::Ptr message = builder.message();
-
-    if (!note->property("relatedUid").toString().isEmpty()) {
-        auto relatedHeader = new KMime::Headers::Generic("X-Zanshin-RelatedProjectUid");
-        relatedHeader->from7BitString(note->property("relatedUid").toString().toUtf8());
-        message->appendHeader(relatedHeader);
-    }
-
-    Akonadi::Item item;
-    if (note->property("itemId").isValid()) {
-        item.setId(note->property("itemId").value<Akonadi::Item::Id>());
-    }
-    item.setMimeType(Akonadi::NoteUtils::noteMimeType());
-    item.setPayload(message);
-    return item;
-}
-
 bool Serializer::isProjectItem(Item item)
 {
     if (!item.hasPayload<KCalCore::Todo::Ptr>())
         return false;
 
-    return !isTaskItem(item);
+    auto todo = item.payload<KCalCore::Todo::Ptr>();
+    return !todo->customProperty(Serializer::customPropertyAppName(), Serializer::customPropertyIsProject()).isEmpty();
 }
 
 Domain::Project::Ptr Serializer::createProjectFromItem(Item item)
@@ -566,7 +470,7 @@ Item Serializer::createItemFromProject(Domain::Project::Ptr project)
     auto todo = KCalCore::Todo::Ptr::create();
 
     todo->setSummary(project->name());
-    todo->setCustomProperty("Zanshin", "Project", QStringLiteral("1"));
+    todo->setCustomProperty(Serializer::customPropertyAppName(), Serializer::customPropertyIsProject(), QStringLiteral("1"));
 
     if (project->property("todoUid").isValid()) {
         todo->setUid(project->property("todoUid").toString());
@@ -595,120 +499,160 @@ bool Serializer::isProjectChild(Domain::Project::Ptr project, Item item)
         && todoUid == relatedUid;
 }
 
-Domain::Context::Ptr Serializer::createContextFromTag(Akonadi::Tag tag)
+static QStringList extractContexts(KCalCore::Todo::Ptr todo)
 {
-    if (!isContext(tag))
-        return Domain::Context::Ptr();
-
-    auto context = Domain::Context::Ptr::create();
-    updateContextFromTag(context, tag);
-    return context;
-}
-
-Akonadi::Tag Serializer::createTagFromContext(Domain::Context::Ptr context)
-{
-    auto tag = Akonadi::Tag();
-    tag.setName(context->name());
-    tag.setType(Akonadi::SerializerInterface::contextTagType());
-    tag.setGid(QByteArray(context->name().toLatin1()));
-
-    if (context->property("tagId").isValid())
-        tag.setId(context->property("tagId").value<Akonadi::Tag::Id>());
-
-    return tag;
-}
-
-void Serializer::updateContextFromTag(Domain::Context::Ptr context, Akonadi::Tag tag)
-{
-    if (!isContext(tag))
-        return;
-
-    context->setProperty("tagId", tag.id());
-    context->setName(tag.name());
-}
-
-bool Serializer::hasContextTags(Item item) const
-{
-    using namespace std::placeholders;
-    Tag::List tags = item.tags();
-    return std::any_of(tags.constBegin(), tags.constEnd(),
-                       std::bind(Utils::mem_fn(&Serializer::isContext), this, _1));
-}
-
-bool Serializer::hasAkonadiTags(Item item) const
-{
-    using namespace std::placeholders;
-    Tag::List tags = item.tags();
-    return std::any_of(tags.constBegin(), tags.constEnd(),
-                       std::bind(Utils::mem_fn(&Serializer::isAkonadiTag), this, _1));
-}
-
-bool Serializer::isContext(const Akonadi::Tag &tag) const
-{
-    return (tag.type() == Akonadi::SerializerInterface::contextTagType());
-}
-
-bool Serializer::isAkonadiTag(const Tag &tag) const
-{
-    return tag.type() == Akonadi::Tag::PLAIN;
-}
-
-bool Serializer::isContextTag(const Domain::Context::Ptr &context, const Akonadi::Tag &tag) const
-{
-    return (context->property("tagId").value<Akonadi::Tag::Id>() == tag.id());
+    const QString contexts = todo->customProperty(Serializer::customPropertyAppName(), Serializer::customPropertyContextList());
+    return contexts.split(',', QString::SkipEmptyParts);
 }
 
 bool Serializer::isContextChild(Domain::Context::Ptr context, Item item) const
 {
-    if (!context->property("tagId").isValid())
+    if (!context->property("todoUid").isValid())
         return false;
 
-    auto tagId = context->property("tagId").value<Akonadi::Tag::Id>();
-    Akonadi::Tag tag(tagId);
+    if (!item.hasPayload<KCalCore::Todo::Ptr>())
+        return false;
 
-    return item.hasTag(tag);
+    auto contextUid = context->property("todoUid").toString();
+    auto todo = item.payload<KCalCore::Todo::Ptr>();
+    const auto contextList = extractContexts(todo);
+    return contextList.contains(contextUid);
 }
 
-Domain::Tag::Ptr Serializer::createTagFromAkonadiTag(Akonadi::Tag akonadiTag)
+bool Serializer::isContext(Item item)
 {
-    if (!isAkonadiTag(akonadiTag))
-        return Domain::Tag::Ptr();
+    if (!item.hasPayload<KCalCore::Todo::Ptr>())
+        return false;
 
-    auto tag = Domain::Tag::Ptr::create();
-    updateTagFromAkonadiTag(tag, akonadiTag);
-    return tag;
+    auto todo = item.payload<KCalCore::Todo::Ptr>();
+    return !todo->customProperty(Serializer::customPropertyAppName(), Serializer::customPropertyIsContext()).isEmpty();
 }
 
-void Serializer::updateTagFromAkonadiTag(Domain::Tag::Ptr tag, Akonadi::Tag akonadiTag)
+Domain::Context::Ptr Serializer::createContextFromItem(Item item)
 {
-    if (!isAkonadiTag(akonadiTag))
+    if (!isContext(item))
+        return {};
+
+    auto context = Domain::Context::Ptr::create();
+    updateContextFromItem(context, item);
+    return context;
+}
+
+Akonadi::Item Serializer::createItemFromContext(Domain::Context::Ptr context)
+{
+    auto todo = KCalCore::Todo::Ptr::create();
+
+    todo->setSummary(context->name());
+    todo->setCustomProperty(Serializer::customPropertyAppName(), Serializer::customPropertyIsContext(), QStringLiteral("1"));
+
+    if (context->property("todoUid").isValid()) {
+        todo->setUid(context->property("todoUid").toString());
+    }
+
+    auto item = Akonadi::Item();
+    if (context->property("itemId").isValid()) {
+        item.setId(context->property("itemId").value<Akonadi::Item::Id>());
+    }
+    if (context->property("parentCollectionId").isValid()) {
+        auto parentId = context->property("parentCollectionId").value<Akonadi::Collection::Id>();
+        item.setParentCollection(Akonadi::Collection(parentId));
+    }
+    item.setMimeType(KCalCore::Todo::todoMimeType());
+    item.setPayload(todo);
+    return item;
+}
+
+void Serializer::updateContextFromItem(Domain::Context::Ptr context, Item item)
+{
+    if (!isContext(item))
         return;
 
-    tag->setProperty("tagId", akonadiTag.id());
-    tag->setName(akonadiTag.name());
+    auto todo = item.payload<KCalCore::Todo::Ptr>();
+
+    context->setName(todo->summary());
+    context->setProperty("itemId", item.id());
+    context->setProperty("parentCollectionId", item.parentCollection().id());
+    context->setProperty("todoUid", todo->uid());
 }
 
-Akonadi::Tag Serializer::createAkonadiTagFromTag(Domain::Tag::Ptr tag)
+void Serializer::addContextToTask(Domain::Context::Ptr context, Item item)
 {
-    auto akonadiTag = Akonadi::Tag();
-    akonadiTag.setName(tag->name());
-    akonadiTag.setType(Akonadi::Tag::PLAIN);
-    akonadiTag.setGid(QByteArray(tag->name().toLatin1()));
+    if (!isTaskItem(item)) {
+        qWarning() << "Cannot add context to a non-task" << item.id();
+        return;
+    }
 
-    const auto tagProperty = tag->property("tagId");
-    if (tagProperty.isValid())
-        akonadiTag.setId(tagProperty.value<Akonadi::Tag::Id>());
+    auto todo = item.payload<KCalCore::Todo::Ptr>();
 
-    return akonadiTag;
+    if (!context->property("todoUid").isValid())
+        return;
+
+    auto contextUid = context->property("todoUid").toString();
+    auto contextList = extractContexts(todo);
+    if (!contextList.contains(contextUid))
+        contextList.append(contextUid);
+    todo->setCustomProperty(Serializer::customPropertyAppName(), Serializer::customPropertyContextList(), contextList.join(','));
+
+    item.setPayload<KCalCore::Todo::Ptr>(todo);
 }
 
-bool Serializer::isTagChild(Domain::Tag::Ptr tag, Akonadi::Item item)
+void Serializer::removeContextFromTask(Domain::Context::Ptr context, Item item)
 {
-    if (!tag->property("tagId").isValid())
-        return false;
+    if (!isTaskItem(item)) {
+        qWarning() << "Cannot remove context from a non-task" << item.id();
+        return;
+    }
 
-    auto tagId = tag->property("tagId").value<Akonadi::Tag::Id>();
-    Akonadi::Tag akonadiTag(tagId);
+    auto todo = item.payload<KCalCore::Todo::Ptr>();
 
-    return item.hasTag(akonadiTag);
+    if (!context->property("todoUid").isValid())
+        return;
+
+    auto contextUid = context->property("todoUid").toString();
+    QStringList contextList = extractContexts(todo);
+    contextList.removeAll(contextUid);
+    if (contextList.isEmpty())
+        todo->removeCustomProperty(Serializer::customPropertyAppName(), Serializer::customPropertyContextList());
+    else
+        todo->setCustomProperty(Serializer::customPropertyAppName(), Serializer::customPropertyContextList(), contextList.join(','));
+
+    item.setPayload<KCalCore::Todo::Ptr>(todo);
+}
+
+QString Serializer::contextUid(Item item)
+{
+    if (!isContext(item))
+        return {};
+
+    auto todo = item.payload<KCalCore::Todo::Ptr>();
+    return todo->uid();
+}
+
+// KCalCore's CustomProperties doesn't implement case insensitivity
+// and some CALDAV servers make everything uppercase. So do like most of kdepim
+// and use uppercase property names.
+
+QByteArray Serializer::customPropertyAppName()
+{
+    return QByteArrayLiteral("ZANSHIN");
+}
+
+QByteArray Serializer::customPropertyIsProject()
+{
+    return QByteArrayLiteral("ISPROJECT");
+}
+
+QByteArray Serializer::customPropertyIsContext()
+{
+    return QByteArrayLiteral("ISCONTEXT");
+}
+
+QByteArray Serializer::customPropertyIsRunning()
+{
+    return QByteArrayLiteral("ISRUNNING");
+}
+
+QByteArray Serializer::customPropertyContextList()
+{
+    return QByteArrayLiteral("CONTEXTLIST");
 }
