@@ -27,10 +27,10 @@
 
 using namespace Utils;
 
-QDateTime DateTime::currentDateTime()
+QDate DateTime::currentDate()
 {
-    QByteArray overrideDatetime = qgetenv("ZANSHIN_OVERRIDE_DATETIME");
-    QDateTime customDateTime = QDateTime::fromString(QString::fromLocal8Bit(overrideDatetime), Qt::ISODate);
+    QByteArray overrideDate = qgetenv("ZANSHIN_OVERRIDE_DATE");
+    QDate customDate = QDate::fromString(QString::fromLocal8Bit(overrideDate), Qt::ISODate);
 
-    return customDateTime.isValid() ? customDateTime : QDateTime::currentDateTime();
+    return customDate.isValid() ? customDate : QDate::currentDate();
 }
