@@ -23,8 +23,6 @@
 
 #include "messagebox.h"
 
-#include <QInputDialog>
-
 Widgets::MessageBox::~MessageBox()
 {
 }
@@ -33,8 +31,3 @@ QMessageBox::Button Widgets::MessageBox::askConfirmation(QWidget *parent, const
 {
     return QMessageBox::question(parent, title, text, QMessageBox::Yes | QMessageBox::No);
 }
-
-QString Widgets::MessageBox::askTextInput(QWidget *parent, const QString &title, const QString &text)
-{
-    return QInputDialog::getText(parent, title, text);
-}
