@@ -24,6 +24,7 @@
 #include <QApplication>
 #include <QBoxLayout>
 #include <QDockWidget>
+#include <QProcess>
 #include <QAction>
 
 #include <KActionCollection>
@@ -31,18 +32,21 @@
 
 #include <KXmlGuiWindow>
 
-#include "widgets/taskapplicationcomponents.h"
+#include <KConfigGroup>
+#include <KSharedConfig>
+
+#include "widgets/applicationcomponents.h"
 #include "widgets/availablepagesview.h"
 #include "widgets/availablesourcesview.h"
 #include "widgets/editorview.h"
 #include "widgets/pageview.h"
 
-#include "presentation/taskapplicationmodel.h"
+#include "presentation/applicationmodel.h"
 
 #include "utils/dependencymanager.h"
+#include "integration/dependencies.h"
 
 #include "aboutdata.h"
-#include "dependencies.h"
 
 #include <iostream>
 #include <KAboutData>
@@ -53,7 +57,7 @@ int main(int argc, char **argv)
 {
     KLocalizedString::setApplicationDomain("zanshin");
     QApplication app(argc, argv);
-    App::initializeDependencies();
+    Integration::initializeGlobalAppDependencies();
 
     auto aboutData = App::getAboutData();
     QCommandLineParser parser;
@@ -64,9 +68,25 @@ int main(int argc, char **argv)
     parser.process(app);
     aboutData.processCommandLine(&parser);
 
+    KSharedConfig::Ptr config = KSharedConfig::openConfig(QStringLiteral("zanshin-migratorrc"));
+    KConfigGroup group = config->group("Migrations");
+    if (!group.readEntry("MigratedTags", false)) {
+        std::cerr << "Migrating tags, please wait..." << std::endl;
+        QProcess proc;
+        proc.start(QStringLiteral("zanshin-migrator"));
+        proc.waitForFinished(-1);
+        if (proc.exitStatus() == QProcess::CrashExit) {
+            std::cerr << "Migrator crashed!" << std::endl;
+        } else if (proc.exitCode() == 0) {
+            std::cerr << "Migration done" << std::endl;
+        } else {
+            std::cerr << "Migration error, code" << proc.exitCode() << std::endl;
+        }
+    }
+
     auto widget = new QWidget;
-    auto components = new Widgets::TaskApplicationComponents(widget);
-    components->setModel(Presentation::TaskApplicationModel::Ptr::create());
+    auto components = new Widgets::ApplicationComponents(widget);
+    components->setModel(Presentation::ApplicationModel::Ptr::create());
 
     auto layout = new QVBoxLayout;
     layout->setContentsMargins(0, 0, 0, 0);
