@@ -31,10 +31,6 @@
 
 #include <KCalCore/Todo>
 #include <KCalCore/ICalFormat>
-#include <kcalcore_version.h>
-#if KCALCORE_VERSION < QT_VERSION_CHECK(5, 6, 80)
-#include <KDateTime>
-#endif
 
 #include "utils/mem_fn.h"
 
@@ -48,13 +44,8 @@
 #include "akonadi/akonadimonitorimpl.h"
 #include "akonadi/akonadistorage.h"
 #include "akonadi/akonadistoragesettings.h"
-#include "akonadi/akonaditagfetchjobinterface.h"
 #include "akonadi/akonaditimestampattribute.h"
 
-#if KCALCORE_VERSION >= QT_VERSION_CHECK(5, 6, 80)
-#define KDateTime QDateTime
-#endif
-
 using namespace Testlib;
 
 AkonadiStorageTestBase::AkonadiStorageTestBase(QObject *parent)
@@ -62,7 +53,6 @@ AkonadiStorageTestBase::AkonadiStorageTestBase(QObject *parent)
 {
     qRegisterMetaType<Akonadi::Collection>();
     qRegisterMetaType<Akonadi::Item>();
-    qRegisterMetaType<Akonadi::Tag>();
 }
 
 void AkonadiStorageTestBase::cleanupTestCase()
@@ -82,37 +72,22 @@ void AkonadiStorageTestBase::shouldListCollections_data()
     QTest::addColumn<Akonadi::Collection>("collection");
     QTest::addColumn<QStringList>("expectedNames");
     QTest::addColumn<Akonadi::StorageInterface::FetchDepth>("depth");
-    QTest::addColumn<int>("contentTypes");
 
     QTest::newRow("all") << Akonadi::Collection::root()
-                         << QStringList({ "Calendar1", "Calendar2", "Calendar3", "Change me!", "Destroy me!", "Notes" })
-                         << Akonadi::Storage::Recursive
-                         << int(Akonadi::StorageInterface::Notes|Akonadi::StorageInterface::Tasks);
-
-    QTest::newRow("notes") << Akonadi::Collection::root()
-                           << QStringList({ "Notes" })
-                           << Akonadi::Storage::Recursive
-                           << int(Akonadi::StorageInterface::Notes);
-
-    QTest::newRow("tasks") << Akonadi::Collection::root()
-                           << QStringList({ "Calendar1", "Calendar2", "Calendar3", "Change me!", "Destroy me!" })
-                           << Akonadi::Storage::Recursive
-                           << int(Akonadi::StorageInterface::Tasks);
+                         << QStringList({ "Calendar1", "Calendar2", "Calendar3", "Change me!", "Destroy me!" })
+                         << Akonadi::Storage::Recursive;
 
     QTest::newRow("base type") << calendar2()
                                << QStringList({"Calendar2"})
-                               << Akonadi::Storage::Base
-                               << int(Akonadi::StorageInterface::Tasks);
+                               << Akonadi::Storage::Base;
 
     QTest::newRow("firstLevel type") << calendar1()
                                      << QStringList({"Calendar2"})
-                                     << Akonadi::Storage::FirstLevel
-                                     << int(Akonadi::StorageInterface::Tasks);
+                                     << Akonadi::Storage::FirstLevel;
 
     QTest::newRow("recursive type") << calendar1()
                                     << QStringList({"Calendar2", "Calendar3"})
-                                    << Akonadi::Storage::Recursive
-                                    << int(Akonadi::StorageInterface::Tasks);
+                                    << Akonadi::Storage::Recursive;
 }
 
 void AkonadiStorageTestBase::shouldListCollections()
@@ -121,13 +96,11 @@ void AkonadiStorageTestBase::shouldListCollections()
     QFETCH(Akonadi::Collection, collection);
     QFETCH(QStringList, expectedNames);
     QFETCH(Akonadi::StorageInterface::FetchDepth, depth);
-    QFETCH(int, contentTypes);
 
     auto storage = createStorage();
 
     // WHEN
-    auto job = storage->fetchCollections(collection, depth,
-                                         Akonadi::StorageInterface::FetchContentTypes(contentTypes));
+    auto job = storage->fetchCollections(collection, depth);
     AKVERIFYEXEC(job->kjob());
 
     // THEN
@@ -149,8 +122,7 @@ void AkonadiStorageTestBase::shouldRetrieveAllCollectionAncestors()
 
     // WHEN
     auto job = storage->fetchCollections(Akonadi::Collection::root(),
-                                         Akonadi::Storage::Recursive,
-                                         Akonadi::Storage::Tasks|Akonadi::Storage::Notes);
+                                         Akonadi::Storage::Recursive);
     AKVERIFYEXEC(job->kjob());
 
     // THEN
@@ -169,11 +141,15 @@ void AkonadiStorageTestBase::shouldListFullItemsInACollection()
 {
     // GIVEN
     auto storage = createStorage();
-    const QStringList expectedRemoteIds = { "{1d33862f-f274-4c67-ab6c-362d56521ff4}",
+    const QStringList expectedRemoteIds = { "rid-errands-context",
+                                            "rid-online-context",
+                                            "{1d33862f-f274-4c67-ab6c-362d56521ff4}",
                                             "{1d33862f-f274-4c67-ab6c-362d56521ff5}",
                                             "{1d33862f-f274-4c67-ab6c-362d56521ff6}",
                                             "{7824df00-2fd6-47a4-8319-52659dc82005}",
-                                            "{7824df00-2fd6-47a4-8319-52659dc82006}" };
+                                            "{7824df00-2fd6-47a4-8319-52659dc82006}",
+                                            "{d0159c99-0d23-41fa-bb5f-tasktoremove}",
+                                          };
 
     // WHEN
     auto job = storage->fetchItems(calendar2());
@@ -184,18 +160,16 @@ void AkonadiStorageTestBase::shouldListFullItemsInACollection()
     QStringList itemRemoteIds;
     itemRemoteIds.reserve(items.size());
     foreach (const auto &item, items) {
-        itemRemoteIds << item.remoteId();
+        const auto rid = item.remoteId();
+        itemRemoteIds << rid;
         QVERIFY(item.loadedPayloadParts().contains(Akonadi::Item::FullPayload));
-        QVERIFY(!item.attributes().isEmpty());
         QVERIFY(item.modificationTime().isValid());
-        QVERIFY(!item.flags().isEmpty());
-
-        Akonadi::Tag::List tags = item.tags();
-        QVERIFY(!item.tags().isEmpty());
-        foreach (const auto &tag, tags) {
-            QVERIFY(tag.isValid());
-            QVERIFY(!tag.name().isEmpty());
-            QVERIFY(!tag.type().isEmpty());
+        if (rid.endsWith("context")) {
+            QVERIFY2(item.attributes().isEmpty(), qPrintable(rid));
+            QVERIFY2(item.flags().isEmpty(), qPrintable(rid));
+        } else {
+            QVERIFY2(!item.attributes().isEmpty(), qPrintable(rid));
+            QVERIFY2(!item.flags().isEmpty(), qPrintable(rid));
         }
 
         auto parent = item.parentCollection();
@@ -209,72 +183,6 @@ void AkonadiStorageTestBase::shouldListFullItemsInACollection()
     QCOMPARE(itemRemoteIds, expectedRemoteIds);
 }
 
-void AkonadiStorageTestBase::shouldListTags()
-{
-    // GIVEN
-    auto storage = createStorage();
-    const QStringList expectedGids = { "change-me",
-                                       "delete-me",
-                                       "errands-context",
-                                       "online-context",
-                                       "philosophy-tag",
-                                       "physics-tag" };
-
-    // WHEN
-    auto job = storage->fetchTags();
-    AKVERIFYEXEC(job->kjob());
-
-    // THEN
-    auto tags = job->tags();
-    QStringList tagGids;
-    tagGids.reserve(tags.size());
-    foreach (const auto &tag, tags) {
-        tagGids << tag.gid();
-        QVERIFY(!tag.name().isEmpty());
-        QVERIFY(!tag.type().isEmpty());
-    }
-    tagGids.sort();
-
-    QCOMPARE(tagGids, expectedGids);
-}
-
-void AkonadiStorageTestBase::shouldListItemsAssociatedWithTag()
-{
-    // GIVEN
-    auto storage = createStorage();
-    Akonadi::Tag tag = fetchTagByGID(QStringLiteral("errands-context"));
-    const QStringList expectedRemoteIds = { "{1d33862f-f274-4c67-ab6c-362d56521ff4}",
-                                            "{7824df00-2fd6-47a4-8319-52659dc82005}"
-                                          };
-
-    // WHEN
-    auto job = storage->fetchTagItems(tag);
-    AKVERIFYEXEC(job->kjob());
-
-    // THEN
-    auto items = job->items();
-    QStringList itemRemoteIds;
-    itemRemoteIds.reserve(items.size());
-    foreach (const auto &item, items) {
-        itemRemoteIds << item.remoteId();
-
-        QVERIFY(item.loadedPayloadParts().contains(Akonadi::Item::FullPayload));
-        QVERIFY(!item.attributes().isEmpty());
-        QVERIFY(item.modificationTime().isValid());
-        QVERIFY(!item.flags().isEmpty());
-
-        auto parent = item.parentCollection();
-        while (parent != Akonadi::Collection::root()) {
-            QVERIFY(parent.isValid());
-            parent = parent.parentCollection();
-        }
-
-    }
-    itemRemoteIds.sort();
-
-    QCOMPARE(itemRemoteIds, expectedRemoteIds);
-}
-
 void AkonadiStorageTestBase::shouldNotifyCollectionAdded()
 {
     // GIVEN
@@ -344,7 +252,7 @@ void AkonadiStorageTestBase::shouldNotifyCollectionChanged()
     QSignalSpy spy(monitor.data(), &Akonadi::MonitorInterface::collectionChanged);
     MonitorSpy monitorSpy(monitor.data());
 
-    // A colection with an existing id (if we trust the test data)
+    // A collection with an existing id (if we trust the test data)
     Akonadi::Collection collection = fetchCollectionByRID(QStringLiteral("{28ef9f03-4ebc-4e33-970f-f379775894f9}"));
     QVERIFY(collection.isValid());
     collection.setName(QStringLiteral("Bar!"));
@@ -383,8 +291,8 @@ void AkonadiStorageTestBase::shouldNotifyItemAdded()
     todo->setSummary(QStringLiteral("summary"));
     todo->setDescription(QStringLiteral("content"));
     todo->setCompleted(false);
-    todo->setDtStart(KDateTime(QDate(2013, 11, 24)));
-    todo->setDtDue(KDateTime(QDate(2014, 03, 01)));
+    todo->setDtStart(QDateTime(QDate(2013, 11, 24)));
+    todo->setDtDue(QDateTime(QDate(2014, 03, 01)));
 
     // ... as payload of an item...
     Akonadi::Item item;
@@ -421,8 +329,7 @@ void AkonadiStorageTestBase::shouldNotifyItemRemoved()
     QSignalSpy spy(monitor.data(), &Akonadi::MonitorInterface::itemRemoved);
     MonitorSpy monitorSpy(monitor.data());
 
-    const Akonadi::Collection notesCol = fetchCollectionByRID(QStringLiteral("{f5e3f1be-b998-4c56-aa3d-e3a6e7e5493a}"));
-    Akonadi::Item item = fetchItemByRID(QStringLiteral("{d0159c99-0d23-41fa-bb5f-436570140f8b}"), notesCol);
+    Akonadi::Item item = fetchItemByRID(QStringLiteral("{d0159c99-0d23-41fa-bb5f-tasktoremove}"), calendar2());
     QVERIFY(item.isValid());
 
     // WHEN
@@ -458,8 +365,8 @@ void AkonadiStorageTestBase::shouldNotifyItemChanged()
     todo->setSummary(QStringLiteral("summary"));
     todo->setDescription(QStringLiteral("content"));
     todo->setCompleted(false);
-    todo->setDtStart(KDateTime(QDate(2013, 11, 24)));
-    todo->setDtDue(KDateTime(QDate(2014, 03, 01)));
+    todo->setDtStart(QDateTime(QDate(2013, 11, 24)));
+    todo->setDtDue(QDateTime(QDate(2014, 03, 01)));
 
     // ... as payload of an existing item (if we trust the test data)...
     Akonadi::Item item = fetchItemByRID(QStringLiteral("{1d33862f-f274-4c67-ab6c-362d56521ff6}"), calendar2());
@@ -489,187 +396,7 @@ void AkonadiStorageTestBase::shouldNotifyItemChanged()
     }
 }
 
-void AkonadiStorageTestBase::shouldNotifyItemTagAdded()
-{
-    // GIVEN
-
-    // A spied monitor
-    auto monitor = createMonitor();
-    QSignalSpy spy(monitor.data(), &Akonadi::MonitorInterface::itemChanged);
-    MonitorSpy monitorSpy(monitor.data());
-
-    // An existing item (if we trust the test data)...
-    Akonadi::Item item = fetchItemByRID(QStringLiteral("{1d33862f-f274-4c67-ab6c-362d56521ff5}"), calendar2());
-    QVERIFY(item.isValid());
-    item.setMimeType(QStringLiteral("application/x-vnd.akonadi.calendar.todo"));
-
-    // An existing tag (if we trust the test data)
-    Akonadi::Tag tag(5);
-
-    // WHEN
-    item.setTag(tag);
-    auto storage = createStorage();
-    auto job = storage->updateItem(item);
-    AKVERIFYEXEC(job);
-    monitorSpy.waitForStableState();
-    QTRY_VERIFY(!spy.isEmpty());
-
-    // THEN
-    QCOMPARE(spy.size(), 1);
-    auto notifiedItem = spy.takeFirst().at(0).value<Akonadi::Item>();
-    QCOMPARE(notifiedItem.id(), item.id());
-    QVERIFY(notifiedItem.hasPayload<KCalCore::Todo::Ptr>());
-
-    Akonadi::Tag::List notifiedTags = notifiedItem.tags();
-
-    QVERIFY(notifiedTags.contains(tag));
-    foreach (const auto &tag, notifiedTags) {
-        QVERIFY(tag.isValid());
-        QVERIFY(!tag.name().isEmpty());
-        QVERIFY(!tag.type().isEmpty());
-    }
-
-    auto parent = notifiedItem.parentCollection();
-    while (parent != Akonadi::Collection::root()) {
-        QVERIFY(parent.isValid());
-        parent = parent.parentCollection();
-    }
-}
-
-void AkonadiStorageTestBase::shouldNotifyItemTagRemoved() // aka dissociate
-{
-    // GIVEN
-    auto storage = createStorage();
-    Akonadi::Tag tag = fetchTagByGID(QStringLiteral("philosophy-tag"));
-    const QString expectedRemoteIds = {QStringLiteral("{7824df00-2fd6-47a4-8319-52659dc82006}")};
-    auto job = storage->fetchTagItems(tag);
-    AKVERIFYEXEC(job->kjob());
-
-    auto item = job->items().at(0);
-    QCOMPARE(item.remoteId(), expectedRemoteIds);
-
-    QVERIFY(item.loadedPayloadParts().contains(Akonadi::Item::FullPayload));
-    QVERIFY(!item.attributes().isEmpty());
-    QVERIFY(item.modificationTime().isValid());
-    QVERIFY(!item.flags().isEmpty());
-    QVERIFY(!item.tags().isEmpty());
-
-    // A spied monitor
-    auto monitor = createMonitor();
-    QSignalSpy spy(monitor.data(), &Akonadi::MonitorInterface::itemChanged);
-    MonitorSpy monitorSpy(monitor.data());
-
-    // WHEN
-    item.clearTag(tag);
-    auto jobUpdate = storage->updateItem(item);
-    AKVERIFYEXEC(jobUpdate);
-    monitorSpy.waitForStableState();
-    QTRY_VERIFY(!spy.isEmpty());
-
-    // THEN
-    QCOMPARE(spy.size(), 1);
-    auto notifiedItem = spy.takeFirst().at(0).value<Akonadi::Item>();
-    QCOMPARE(notifiedItem.id(), item.id());
-    QVERIFY(!notifiedItem.tags().contains(tag));
-}
-
-void AkonadiStorageTestBase::shouldNotifyTagAdded()
-{
-    // GIVEN
-
-    // A spied monitor
-    auto monitor = createMonitor();
-    QSignalSpy spy(monitor.data(), &Akonadi::MonitorInterface::tagAdded);
-    MonitorSpy monitorSpy(monitor.data());
-
-    // A tag
-    Akonadi::Tag tag;
-    tag.setGid("gid");
-    tag.setName(QStringLiteral("name"));
-    tag.setType("type");
-
-    // WHEN
-    auto storage = createStorage();
-    auto job = storage->createTag(tag);
-    AKVERIFYEXEC(job);
-    monitorSpy.waitForStableState();
-    QTRY_VERIFY(!spy.isEmpty());
-
-    // THEN
-    QCOMPARE(spy.size(), 1);
-    auto notifiedTag = spy.takeFirst().at(0).value<Akonadi::Tag>();
-    QCOMPARE(notifiedTag.gid(), tag.gid());
-    QCOMPARE(notifiedTag.name(), tag.name());
-    QCOMPARE(notifiedTag.type(), tag.type());
-}
-
-void AkonadiStorageTestBase::shouldNotifyTagRemoved()
-{
-    // GIVEN
-
-    // An existing tag (if we trust the test data) connected to an existing item tagged to it
-    auto storage = createStorage();
-    Akonadi::Tag tag = fetchTagByGID(QStringLiteral("delete-me"));
-    // NOTE : this item was linked to the delete-me tag during test time
-    const QString expectedRemoteIds = {QStringLiteral("{1d33862f-f274-4c67-ab6c-362d56521ff5}")};
-    auto job = storage->fetchTagItems(tag);
-    AKVERIFYEXEC(job->kjob());
-
-    QCOMPARE(job->items().size(), 1);
-    auto itemTagged = job->items().at(0);
-    QCOMPARE(itemTagged.remoteId(), expectedRemoteIds);
-
-    // A spied monitor
-    auto monitor = createMonitor();
-    QSignalSpy spy(monitor.data(), &Akonadi::MonitorInterface::tagRemoved);
-    QSignalSpy spyItemChanged(monitor.data(), &Akonadi::MonitorInterface::itemChanged);
-    MonitorSpy monitorSpy(monitor.data());
-
-    // WHEN
-    auto jobDelete = storage->removeTag(tag);
-    AKVERIFYEXEC(jobDelete);
-    monitorSpy.waitForStableState();
-    QTRY_VERIFY(!spy.isEmpty());
-    QTRY_VERIFY(!spyItemChanged.isEmpty());
-
-    // THEN
-    QCOMPARE(spy.size(), 1);
-    auto notifiedTag = spy.takeFirst().at(0).value<Akonadi::Tag>();
-    QCOMPARE(notifiedTag.id(), tag.id());
-
-    QCOMPARE(spyItemChanged.size(), 1);
-    auto notifiedItem = spyItemChanged.takeFirst().at(0).value<Akonadi::Item>();
-    QCOMPARE(notifiedItem.id(), itemTagged.id());
-}
-
-void AkonadiStorageTestBase::shouldNotifyTagChanged()
-{
-    // GIVEN
-
-    // A spied monitor
-    auto monitor = createMonitor();
-    QSignalSpy spy(monitor.data(), &Akonadi::MonitorInterface::tagChanged);
-    MonitorSpy monitorSpy(monitor.data());
-
-    // An existing tag (if we trust the test data)
-    Akonadi::Tag tag(6);
-    tag.setName(QStringLiteral("Oh it changed!"));
-
-    // WHEN
-    auto storage = createStorage();
-    auto job = storage->updateTag(tag);
-    AKVERIFYEXEC(job);
-    monitorSpy.waitForStableState();
-    QTRY_VERIFY(!spy.isEmpty());
-
-    // THEN
-    QCOMPARE(spy.size(), 1);
-    auto notifiedTag = spy.takeFirst().at(0).value<Akonadi::Tag>();
-    QCOMPARE(notifiedTag.id(), tag.id());
-    QCOMPARE(notifiedTag.name(), tag.name());
-}
-
-void AkonadiStorageTestBase::shouldReadDefaultNoteCollectionFromSettings()
+void AkonadiStorageTestBase::shouldReadDefaultCollectionFromSettings()
 {
     // GIVEN
 
@@ -677,24 +404,10 @@ void AkonadiStorageTestBase::shouldReadDefaultNoteCollectionFromSettings()
     auto storage = createStorage();
 
     // WHEN
-    Akonadi::StorageSettings::instance().setDefaultNoteCollection(Akonadi::Collection(24));
+    Akonadi::StorageSettings::instance().setDefaultCollection(Akonadi::Collection(24));
 
     // THEN
-    QCOMPARE(storage->defaultNoteCollection(), Akonadi::Collection(24));
-}
-
-void AkonadiStorageTestBase::shouldReadDefaultTaskCollectionFromSettings()
-{
-    // GIVEN
-
-    // A storage implementation
-    auto storage = createStorage();
-
-    // WHEN
-    Akonadi::StorageSettings::instance().setDefaultTaskCollection(Akonadi::Collection(24));
-
-    // THEN
-    QCOMPARE(storage->defaultTaskCollection(), Akonadi::Collection(24));
+    QCOMPARE(storage->defaultCollection(), Akonadi::Collection(24));
 }
 
 void AkonadiStorageTestBase::shouldUpdateItem()
@@ -730,18 +443,7 @@ void AkonadiStorageTestBase::shouldUpdateItem()
     auto notifiedItem = spy.takeFirst().at(0).value<Akonadi::Item>();
     QCOMPARE(notifiedItem.id(), item.id());
 
-    // KCalCore 4.83 fixes this bug
-#if KCALCORE_VERSION < 0x045300
-    QCOMPARE(notifiedItem.payload<KCalCore::Todo::Ptr>()->uid(), todo->uid());
-    QCOMPARE(notifiedItem.payload<KCalCore::Todo::Ptr>()->summary(), todo->summary());
-    QCOMPARE(notifiedItem.payload<KCalCore::Todo::Ptr>()->description(), todo->description());
-    QEXPECT_FAIL("", "Bug introduced by 76c686bc1de3a5d16956a627744ce352bc28d12a in KCalCore", Continue);
     QCOMPARE(*notifiedItem.payload<KCalCore::Todo::Ptr>(), *todo);
-    QEXPECT_FAIL("", "Bug introduced by 76c686bc1de3a5d16956a627744ce352bc28d12a in KCalCore", Continue);
-    QCOMPARE(notifiedItem.payload<KCalCore::Todo::Ptr>()->status(), todo->status());
-#else
-    QCOMPARE(*notifiedItem.payload<KCalCore::Todo::Ptr>(), *todo);
-#endif
 }
 
 void AkonadiStorageTestBase::shouldUseTransaction()
@@ -809,8 +511,8 @@ void AkonadiStorageTestBase::shouldCreateItem()
     todo->setSummary(QStringLiteral("summary"));
     todo->setDescription(QStringLiteral("content"));
     todo->setCompleted(false);
-    todo->setDtStart(KDateTime(QDate(2013, 11, 24)));
-    todo->setDtDue(KDateTime(QDate(2014, 03, 01)));
+    todo->setDtStart(QDateTime(QDate(2013, 11, 24)));
+    todo->setDtDue(QDateTime(QDate(2014, 03, 01)));
 
     // ... as payload of a new item
     Akonadi::Item item;
@@ -967,92 +669,6 @@ void AkonadiStorageTestBase::shouldDeleteItems()
     QCOMPARE(notifiedItem.id(), item2.id());
 }
 
-void AkonadiStorageTestBase::shouldCreateTag()
-{
-    // GIVEN
-
-    // A storage implementation
-    auto storage = createStorage();
-
-    // A spied monitor
-    auto monitor = createMonitor();
-    QSignalSpy spy(monitor.data(), &Akonadi::MonitorInterface::tagAdded);
-    MonitorSpy monitorSpy(monitor.data());
-
-    // A tag
-    Akonadi::Tag tag;
-    QString name = QStringLiteral("Tag42");
-    const QByteArray type = QByteArray("Zanshin-Context");
-    const QByteArray gid = QByteArray(name.toLatin1());
-    tag.setName(name);
-    tag.setType(QByteArray("Zanshin-Context"));
-    tag.setGid(gid);
-
-    // WHEN
-    auto job = storage->createTag(tag);
-    AKVERIFYEXEC(job);
-    monitorSpy.waitForStableState();
-    QTRY_VERIFY(!spy.isEmpty());
-
-    // THEN
-    QCOMPARE(spy.size(), 1);
-    auto notifiedTag = spy.takeFirst().at(0).value<Akonadi::Tag>();
-    QCOMPARE(notifiedTag.name(), name);
-    QCOMPARE(notifiedTag.type(), type);
-    QCOMPARE(notifiedTag.gid(), gid);
-}
-
-void AkonadiStorageTestBase::shouldRemoveTag()
-{
-
-    // GIVEN
-    auto storage = createStorage();
-
-    // A spied monitor
-    auto monitor = createMonitor();
-    QSignalSpy spy(monitor.data(), &Akonadi::MonitorInterface::tagRemoved);
-    MonitorSpy monitorSpy(monitor.data());
-
-    // An existing tag
-    Akonadi::Tag tag = fetchTagByGID(QStringLiteral("errands-context"));
-
-    // WHEN
-    auto job = storage->removeTag(tag);
-    AKVERIFYEXEC(job);
-    monitorSpy.waitForStableState();
-    QTRY_VERIFY(!spy.isEmpty());
-
-    // THEN
-    QCOMPARE(spy.size(), 1);
-    auto notifiedTag = spy.takeFirst().at(0).value<Akonadi::Tag>();
-    QCOMPARE(notifiedTag.id(), tag.id());
-}
-
-void AkonadiStorageTestBase::shouldUpdateTag()
-{
-    // GIVEN
-    auto storage = createStorage();
-
-    // A spied monitor
-    auto monitor = createMonitor();
-    QSignalSpy spy(monitor.data(), &Akonadi::MonitorInterface::tagChanged);
-    MonitorSpy monitorSpy(monitor.data());
-
-    // An existing tag
-    Akonadi::Tag tag = fetchTagByGID(QStringLiteral("change-me"));
-
-    // WHEN
-    auto job = storage->updateTag(tag);
-    AKVERIFYEXEC(job);
-    monitorSpy.waitForStableState();
-    QTRY_VERIFY(!spy.isEmpty());
-
-    // THEN
-    QCOMPARE(spy.size(), 1);
-    auto notifiedTag = spy.takeFirst().at(0).value<Akonadi::Tag>();
-    QCOMPARE(notifiedTag.id(), tag.id());
-}
-
 void AkonadiStorageTestBase::shouldUpdateCollection()
 {
     // GIVEN
@@ -1157,36 +773,6 @@ void AkonadiStorageTestBase::shouldNotifyCollectionSelectionChanges()
     QVERIFY(!notifiedCollection.attribute<Akonadi::ApplicationSelectedAttribute>()->isSelected());
 }
 
-void AkonadiStorageTestBase::shouldNotNotifyCollectionSelectionChangesForIrrelevantCollections()
-{
-    // GIVEN
-
-    // A storage implementation
-    auto storage = createStorage();
-
-    // An existing collection
-    Akonadi::Collection collection = emails();
-
-    // A spied monitor
-    auto monitor = createMonitor();
-    QSignalSpy changeSpy(monitor.data(), &Akonadi::MonitorInterface::collectionChanged);
-    QSignalSpy selectionSpy(monitor.data(), &Akonadi::MonitorInterface::collectionSelectionChanged);
-    MonitorSpy monitorSpy(monitor.data());
-
-    // WHEN
-    auto attr = new Akonadi::ApplicationSelectedAttribute;
-    attr->setSelected(false);
-    collection.addAttribute(attr);
-    auto job = storage->updateCollection(collection);
-    AKVERIFYEXEC(job);
-    monitorSpy.waitForStableState();
-    QTRY_VERIFY(!changeSpy.isEmpty());
-
-    // THEN
-    QCOMPARE(changeSpy.size(), 1);
-    QVERIFY(selectionSpy.isEmpty());
-}
-
 Akonadi::Item AkonadiStorageTestBase::fetchItemByRID(const QString &remoteId, const Akonadi::Collection &collection)
 {
     Akonadi::Item item;
@@ -1212,7 +798,7 @@ Akonadi::Collection AkonadiStorageTestBase::fetchCollectionByRID(const QString &
     Akonadi::Collection collection;
     collection.setRemoteId(remoteId);
 
-    auto job = createStorage()->fetchCollections(collection, Akonadi::StorageInterface::Base, Akonadi::StorageInterface::AllContent);
+    auto job = createStorage()->fetchCollections(collection, Akonadi::StorageInterface::Base);
     job->setResource(QStringLiteral("akonadi_knut_resource_0"));
     if (!job->kjob()->exec()) {
         qWarning() << job->kjob()->errorString() << remoteId;
@@ -1227,23 +813,6 @@ Akonadi::Collection AkonadiStorageTestBase::fetchCollectionByRID(const QString &
     return job->collections().at(0);
 }
 
-Akonadi::Tag AkonadiStorageTestBase::fetchTagByGID(const QString &gid)
-{
-    auto job = createStorage()->fetchTags();
-    if (!job->kjob()->exec()) {
-        qWarning() << job->kjob()->errorString();
-        return Akonadi::Tag();
-    }
-
-    auto tags = job->tags();
-    foreach (const auto &tag, tags) {
-        if (tag.gid() == gid)
-            return tag;
-    }
-
-    return Akonadi::Tag();
-}
-
 Akonadi::Collection AkonadiStorageTestBase::calendar1()
 {
     return fetchCollectionByRID(QStringLiteral("{cdc229c7-a9b5-4d37-989d-a28e372be2a9}"));
