@@ -43,38 +43,18 @@ typedef std::function<void(Akonadi::StorageSettings *, const Akonadi::Collection
 Q_DECLARE_METATYPE(SetDefaultCollectionFunction)
 typedef std::function<Akonadi::Collection(Akonadi::StorageSettings *)> GetDefaultCollectionFunction;
 Q_DECLARE_METATYPE(GetDefaultCollectionFunction)
-Q_DECLARE_METATYPE(Akonadi::StorageInterface::FetchContentType)
 
 class AkonadiDataSourceQueriesTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit AkonadiDataSourceQueriesTest(QObject *parent = Q_NULLPTR)
+    explicit AkonadiDataSourceQueriesTest(QObject *parent = nullptr)
         : QObject(parent)
     {
         qRegisterMetaType<QueryFunction>();
     }
 
 private slots:
-    void shouldCheckIfASourceIsDefaultFromSettings_data()
-    {
-        QTest::addColumn<Akonadi::StorageInterface::FetchContentType>("contentType");
-        QTest::addColumn<SetDefaultCollectionFunction>("setDefaultCollection");
-        QTest::addColumn<GetDefaultCollectionFunction>("getDefaultCollection");
-
-        {
-            SetDefaultCollectionFunction setFunction = Utils::mem_fn(&Akonadi::StorageSettings::setDefaultNoteCollection);
-            GetDefaultCollectionFunction getFunction = Utils::mem_fn(&Akonadi::StorageSettings::defaultNoteCollection);
-            QTest::newRow("notes") << Akonadi::StorageInterface::Notes << setFunction << getFunction;
-        }
-
-        {
-            SetDefaultCollectionFunction setFunction = Utils::mem_fn(&Akonadi::StorageSettings::setDefaultTaskCollection);
-            GetDefaultCollectionFunction getFunction = Utils::mem_fn(&Akonadi::StorageSettings::defaultTaskCollection);
-            QTest::newRow("tasks") << Akonadi::StorageInterface::Tasks << setFunction << getFunction;
-        }
-    }
-
     void shouldCheckIfASourceIsDefaultFromSettings()
     {
         // GIVEN
@@ -82,27 +62,19 @@ private slots:
         const auto maxId = qint64(44);
         const auto defaultId = qint64(43);
 
-        QFETCH(Akonadi::StorageInterface::FetchContentType, contentType);
-        QFETCH(SetDefaultCollectionFunction, setDefaultCollection);
-
         // A default collection for saving
-        setDefaultCollection(&Akonadi::StorageSettings::instance(),
-                             Akonadi::Collection(defaultId));
+        Akonadi::StorageSettings::instance().setDefaultCollection(Akonadi::Collection(defaultId));
 
         // A few data sources
         AkonadiFakeData data;
         for (auto id = minId; id <= maxId; ++id) {
             auto col = GenCollection().withId(id).withName(QString::number(id)).withRootAsParent();
-            if (contentType == Akonadi::StorageInterface::Tasks)
-                data.createCollection(col.withTaskContent());
-            else
-                data.createCollection(col.withTaskContent());
+            data.createCollection(col.withTaskContent());
         }
 
         // WHEN
         auto serializer = Akonadi::SerializerInterface::Ptr(new Akonadi::Serializer);
-        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(contentType,
-                                                                                         Akonadi::StorageInterface::Ptr(data.createStorage()),
+        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Ptr(data.createStorage()),
                                                                                          serializer,
                                                                                          Akonadi::MonitorInterface::Ptr(data.createMonitor())));
 
@@ -113,11 +85,6 @@ private slots:
         }
     }
 
-    void shouldStoreDefaultSourceInTheSettingsAndNotify_data()
-    {
-        shouldCheckIfASourceIsDefaultFromSettings_data();
-    }
-
     void shouldStoreDefaultSourceInTheSettingsAndNotify()
     {
         // GIVEN
@@ -125,27 +92,19 @@ private slots:
         const auto maxId = qint64(44);
         const auto defaultId = qint64(43);
 
-        QFETCH(Akonadi::StorageInterface::FetchContentType, contentType);
-        QFETCH(SetDefaultCollectionFunction, setDefaultCollection);
-
         // A default collection for saving
-        setDefaultCollection(&Akonadi::StorageSettings::instance(),
-                             Akonadi::Collection(minId));
+        Akonadi::StorageSettings::instance().setDefaultCollection(Akonadi::Collection(minId));
 
         // A few data sources
         AkonadiFakeData data;
         for (auto id = minId; id <= maxId; ++id) {
             auto col = GenCollection().withId(id).withName(QString::number(id)).withRootAsParent();
-            if (contentType == Akonadi::StorageInterface::Tasks)
-                data.createCollection(col.withTaskContent());
-            else
-                data.createCollection(col.withTaskContent());
+            data.createCollection(col.withTaskContent());
         }
 
         // WHEN
         auto serializer = Akonadi::SerializerInterface::Ptr(new Akonadi::Serializer);
-        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(contentType,
-                                                                                         Akonadi::StorageInterface::Ptr(data.createStorage()),
+        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Ptr(data.createStorage()),
                                                                                          serializer,
                                                                                          Akonadi::MonitorInterface::Ptr(data.createMonitor())));
         QSignalSpy spy(queries->notifier(), &Domain::DataSourceQueriesNotifier::defaultSourceChanged);
@@ -153,29 +112,10 @@ private slots:
         queries->setDefaultSource(defaultSource);
 
         // THEN
-        QFETCH(GetDefaultCollectionFunction, getDefaultCollection);
-        QCOMPARE(getDefaultCollection(&Akonadi::StorageSettings::instance()).id(), defaultId);
+        QCOMPARE(Akonadi::StorageSettings::instance().defaultCollection().id(), defaultId);
         QCOMPARE(spy.count(), 1);
     }
 
-    void shouldLookInAllReportedForTopLevelSources_data()
-    {
-        QTest::addColumn<int>("contentTypes");
-        QTest::addColumn<QStringList>("expectedNames");
-
-        auto expectedNames = QStringList();
-        expectedNames << QStringLiteral("42Task") << QStringLiteral("44Note");
-        QTest::newRow("tasks and notes") << int(Akonadi::StorageInterface::Tasks | Akonadi::StorageInterface::Notes) << expectedNames;
-
-        expectedNames.clear();
-        expectedNames << QStringLiteral("42Task");
-        QTest::newRow("tasks") << int(Akonadi::StorageInterface::Tasks) << expectedNames;
-
-        expectedNames.clear();
-        expectedNames << QStringLiteral("44Note");
-        QTest::newRow("notes") << int(Akonadi::StorageInterface::Notes) << expectedNames;
-    }
-
     void shouldLookInAllReportedForTopLevelSources()
     {
         // GIVEN
@@ -192,9 +132,7 @@ private slots:
         data.createCollection(GenCollection().withId(45).withName(QStringLiteral("45NoteChild")).withParent(44).withNoteContent());
 
         // WHEN
-        QFETCH(int, contentTypes);
-        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::FetchContentTypes(contentTypes),
-                                                                                         Akonadi::StorageInterface::Ptr(data.createStorage()),
+        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Ptr(data.createStorage()),
                                                                                          Akonadi::SerializerInterface::Ptr(new Akonadi::Serializer),
                                                                                          Akonadi::MonitorInterface::Ptr(data.createMonitor())));
 
@@ -213,9 +151,7 @@ private slots:
                        [] (const Domain::DataSource::Ptr &source) { return source->name(); });
         actualNames.sort();
 
-        QFETCH(QStringList, expectedNames);
-        expectedNames.sort();
-        QCOMPARE(actualNames, expectedNames);
+        QCOMPARE(actualNames, QStringList() << "42Task");
     }
 
     void shouldReactToCollectionAddsForTopLevelSources()
@@ -223,8 +159,7 @@ private slots:
         // GIVEN
         AkonadiFakeData data;
 
-        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Tasks | Akonadi::StorageInterface::Notes,
-                                                                                         Akonadi::StorageInterface::Ptr(data.createStorage()),
+        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Ptr(data.createStorage()),
                                                                                          Akonadi::SerializerInterface::Ptr(new Akonadi::Serializer),
                                                                                          Akonadi::MonitorInterface::Ptr(data.createMonitor())));
 
@@ -234,12 +169,10 @@ private slots:
 
         // WHEN
         data.createCollection(GenCollection().withId(42).withName(QStringLiteral("42Task")).withRootAsParent().withTaskContent());
-        data.createCollection(GenCollection().withId(43).withName(QStringLiteral("43Note")).withRootAsParent().withNoteContent());
 
         // THEN
-        QCOMPARE(result->data().size(), 2);
+        QCOMPARE(result->data().size(), 1);
         QCOMPARE(result->data().at(0)->name(), QStringLiteral("42Task"));
-        QCOMPARE(result->data().at(1)->name(), QStringLiteral("43Note"));
     }
 
     void shouldReactToCollectionRemovesForTopLevelSources()
@@ -253,14 +186,13 @@ private slots:
         data.createCollection(GenCollection().withId(44).withName(QStringLiteral("43TaskChild")).withParent(42).withTaskContent());
         data.createCollection(GenCollection().withId(45).withName(QStringLiteral("43NoteChild")).withParent(43).withNoteContent());
 
-        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Tasks | Akonadi::StorageInterface::Notes,
-                                                                                         Akonadi::StorageInterface::Ptr(data.createStorage()),
+        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Ptr(data.createStorage()),
                                                                                          Akonadi::SerializerInterface::Ptr(new Akonadi::Serializer),
                                                                                          Akonadi::MonitorInterface::Ptr(data.createMonitor())));
 
         Domain::QueryResult<Domain::DataSource::Ptr>::Ptr result = queries->findTopLevel();
         TestHelpers::waitForEmptyJobQueue();
-        QCOMPARE(result->data().size(), 2);
+        QCOMPARE(result->data().size(), 1);
 
         // WHEN
         data.removeCollection(Akonadi::Collection(42));
@@ -280,8 +212,7 @@ private slots:
         data.createCollection(GenCollection().withId(43).withName(QStringLiteral("43Note")).withRootAsParent().withNoteContent());
         data.createCollection(GenCollection().withId(44).withName(QStringLiteral("44NoteChild")).withParent(43).withNoteContent());
 
-        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Tasks | Akonadi::StorageInterface::Notes,
-                                                                                         Akonadi::StorageInterface::Ptr(data.createStorage()),
+        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Ptr(data.createStorage()),
                                                                                          Akonadi::SerializerInterface::Ptr(new Akonadi::Serializer),
                                                                                          Akonadi::MonitorInterface::Ptr(data.createMonitor())));
 
@@ -292,17 +223,15 @@ private slots:
                                           replaceHandlerCalled = true;
                                       });
         TestHelpers::waitForEmptyJobQueue();
-        QCOMPARE(result->data().size(), 2);
+        QCOMPARE(result->data().size(), 1);
 
         // WHEN
         data.modifyCollection(GenCollection(data.collection(42)).withName(QStringLiteral("42TaskBis")));
-        data.modifyCollection(GenCollection(data.collection(43)).withName(QStringLiteral("43NoteBis")));
         TestHelpers::waitForEmptyJobQueue();
 
         // THEN
-        QCOMPARE(result->data().size(), 2);
+        QCOMPARE(result->data().size(), 1);
         QCOMPARE(result->data().at(0)->name(), QStringLiteral("42TaskBis"));
-        QCOMPARE(result->data().at(1)->name(), QStringLiteral("43NoteBis"));
         QVERIFY(replaceHandlerCalled);
     }
 
@@ -340,8 +269,7 @@ private slots:
         data.createCollection(GenCollection().withId(42).withRootAsParent().withTaskContent());
         data.createCollection(GenCollection().withId(43).withRootAsParent().withNoteContent());
 
-        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Tasks | Akonadi::StorageInterface::Notes,
-                                                                                         Akonadi::StorageInterface::Ptr(data.createStorage()),
+        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Ptr(data.createStorage()),
                                                                                          Akonadi::SerializerInterface::Ptr(new Akonadi::Serializer),
                                                                                          Akonadi::MonitorInterface::Ptr(data.createMonitor())));
         QFETCH(int, colErrorCode);
@@ -364,24 +292,6 @@ private slots:
         QCOMPARE(result->data().size(), 0);
     }
 
-    void shouldLookInAllReportedForChildSources_data()
-    {
-        QTest::addColumn<int>("contentTypes");
-        QTest::addColumn<QStringList>("expectedNames");
-
-        auto expectedNames = QStringList();
-        expectedNames << QStringLiteral("43TaskFirstChild") << QStringLiteral("45NoteSecondChild");
-        QTest::newRow("tasks and notes") << int(Akonadi::StorageInterface::Tasks | Akonadi::StorageInterface::Notes) << expectedNames;
-
-        expectedNames.clear();
-        expectedNames << QStringLiteral("43TaskFirstChild");
-        QTest::newRow("tasks") << int(Akonadi::StorageInterface::Tasks) << expectedNames;
-
-        expectedNames.clear();
-        expectedNames << QStringLiteral("45NoteSecondChild");
-        QTest::newRow("notes") << int(Akonadi::StorageInterface::Notes) << expectedNames;
-    }
-
     void shouldLookInAllReportedForChildSources()
     {
         // GIVEN
@@ -398,9 +308,7 @@ private slots:
         Domain::DataSource::Ptr topLevelDataSource = serializer->createDataSourceFromCollection(data.collection(42), Akonadi::SerializerInterface::BaseName);
 
         // WHEN
-        QFETCH(int, contentTypes);
-        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::FetchContentTypes(contentTypes),
-                                                                                         Akonadi::StorageInterface::Ptr(data.createStorage()),
+        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Ptr(data.createStorage()),
                                                                                          serializer,
                                                                                          Akonadi::MonitorInterface::Ptr(data.createMonitor())));
 
@@ -419,9 +327,7 @@ private slots:
                        [] (const Domain::DataSource::Ptr &source) { return source->name(); });
         actualNames.sort();
 
-        QFETCH(QStringList, expectedNames);
-        expectedNames.sort();
-        QCOMPARE(actualNames, expectedNames);
+        QCOMPARE(actualNames, QStringList() << QStringLiteral("43TaskFirstChild"));
     }
 
     void shouldReactToCollectionAddsForChildSources()
@@ -436,8 +342,7 @@ private slots:
         auto serializer = Akonadi::Serializer::Ptr(new Akonadi::Serializer);
         Domain::DataSource::Ptr topLevelDataSource = serializer->createDataSourceFromCollection(data.collection(42), Akonadi::SerializerInterface::BaseName);
 
-        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Tasks | Akonadi::StorageInterface::Notes,
-                                                                                         Akonadi::StorageInterface::Ptr(data.createStorage()),
+        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Ptr(data.createStorage()),
                                                                                          serializer,
                                                                                          Akonadi::MonitorInterface::Ptr(data.createMonitor())));
 
@@ -469,14 +374,13 @@ private slots:
         auto serializer = Akonadi::Serializer::Ptr(new Akonadi::Serializer);
         Domain::DataSource::Ptr topLevelDataSource = serializer->createDataSourceFromCollection(data.collection(42), Akonadi::SerializerInterface::BaseName);
 
-        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Tasks | Akonadi::StorageInterface::Notes,
-                                                                                         Akonadi::StorageInterface::Ptr(data.createStorage()),
+        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Ptr(data.createStorage()),
                                                                                          serializer,
                                                                                          Akonadi::MonitorInterface::Ptr(data.createMonitor())));
 
         Domain::QueryResult<Domain::DataSource::Ptr>::Ptr result = queries->findChildren(topLevelDataSource);
         TestHelpers::waitForEmptyJobQueue();
-        QCOMPARE(result->data().size(), 2);
+        QCOMPARE(result->data().size(), 1);
 
         // WHEN
         data.removeCollection(Akonadi::Collection(44));
@@ -500,8 +404,7 @@ private slots:
         auto serializer = Akonadi::Serializer::Ptr(new Akonadi::Serializer);
         Domain::DataSource::Ptr topLevelDataSource = serializer->createDataSourceFromCollection(data.collection(42), Akonadi::SerializerInterface::BaseName);
 
-        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Tasks | Akonadi::StorageInterface::Notes,
-                                                                                         Akonadi::StorageInterface::Ptr(data.createStorage()),
+        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Ptr(data.createStorage()),
                                                                                          serializer,
                                                                                          Akonadi::MonitorInterface::Ptr(data.createMonitor())));
 
@@ -511,16 +414,15 @@ private slots:
                                           replaceHandlerCalled = true;
                                       });
         TestHelpers::waitForEmptyJobQueue();
-        QCOMPARE(result->data().size(), 2);
+        QCOMPARE(result->data().size(), 1);
 
         // WHEN
         data.modifyCollection(GenCollection(data.collection(43)).withName(QStringLiteral("43TaskFirstChildBis")));
 
         // THEN
         TestHelpers::waitForEmptyJobQueue();
-        QCOMPARE(result->data().size(), 2);
+        QCOMPARE(result->data().size(), 1);
         QCOMPARE(result->data().first()->name(), QStringLiteral("43TaskFirstChildBis"));
-        QCOMPARE(result->data().at(1)->name(), QStringLiteral("44NoteSecondChild"));
         QVERIFY(replaceHandlerCalled);
     }
 
@@ -571,8 +473,7 @@ private slots:
                                                            AkonadiFakeStorageBehavior::FetchBehavior(colFetchBehavior));
 
         // WHEN
-        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Tasks | Akonadi::StorageInterface::Notes,
-                                                                                         Akonadi::StorageInterface::Ptr(data.createStorage()),
+        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Ptr(data.createStorage()),
                                                                                          serializer,
                                                                                          Akonadi::MonitorInterface::Ptr(data.createMonitor())));
 
@@ -587,24 +488,6 @@ private slots:
         QCOMPARE(result->data().size(), 0);
     }
 
-    void shouldLookInAllReportedForSelectedSources_data()
-    {
-        QTest::addColumn<int>("contentTypes");
-        QTest::addColumn<QStringList>("expectedNames");
-
-        auto expectedNames = QStringList();
-        expectedNames << QStringLiteral("42Task » 43Task") << QStringLiteral("44Note » 45Note");
-        QTest::newRow("tasks and notes") << int(Akonadi::StorageInterface::Tasks | Akonadi::StorageInterface::Notes) << expectedNames;
-
-        expectedNames.clear();
-        expectedNames << QStringLiteral("42Task » 43Task");
-        QTest::newRow("tasks") << int(Akonadi::StorageInterface::Tasks) << expectedNames;
-
-        expectedNames.clear();
-        expectedNames << QStringLiteral("44Note » 45Note");
-        QTest::newRow("notes") << int(Akonadi::StorageInterface::Notes) << expectedNames;
-    }
-
     void shouldLookInAllReportedForSelectedSources()
     {
         // GIVEN
@@ -617,9 +500,7 @@ private slots:
         data.createCollection(GenCollection().withId(45).withName(QStringLiteral("45Note")).withParent(44).withNoteContent().selected(true));
 
         // WHEN
-        QFETCH(int, contentTypes);
-        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::FetchContentTypes(contentTypes),
-                                                                                         Akonadi::StorageInterface::Ptr(data.createStorage()),
+        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Ptr(data.createStorage()),
                                                                                          Akonadi::SerializerInterface::Ptr(new Akonadi::Serializer),
                                                                                          Akonadi::MonitorInterface::Ptr(data.createMonitor())));
 
@@ -638,9 +519,7 @@ private slots:
                        [] (const Domain::DataSource::Ptr &source) { return source->name(); });
         actualNames.sort();
 
-        QFETCH(QStringList, expectedNames);
-        expectedNames.sort();
-        QCOMPARE(actualNames, expectedNames);
+        QCOMPARE(actualNames, QStringList() << QStringLiteral("42Task » 43Task"));
     }
 
     void shouldReactToCollectionAddsForSelectedSources()
@@ -648,8 +527,7 @@ private slots:
         // GIVEN
         AkonadiFakeData data;
 
-        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Tasks | Akonadi::StorageInterface::Notes,
-                                                                                         Akonadi::StorageInterface::Ptr(data.createStorage()),
+        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Ptr(data.createStorage()),
                                                                                          Akonadi::SerializerInterface::Ptr(new Akonadi::Serializer),
                                                                                          Akonadi::MonitorInterface::Ptr(data.createMonitor())));
 
@@ -664,9 +542,8 @@ private slots:
         data.createCollection(GenCollection().withId(45).withName(QStringLiteral("45Note")).withParent(44).withNoteContent().selected(true));
 
         // THEN
-        QCOMPARE(result->data().size(), 2);
+        QCOMPARE(result->data().size(), 1);
         QCOMPARE(result->data().at(0)->name(), QStringLiteral("42Task » 43Task"));
-        QCOMPARE(result->data().at(1)->name(), QStringLiteral("44Note » 45Note"));
     }
 
     void shouldReactToCollectionRemovesForSelectedSources()
@@ -680,14 +557,13 @@ private slots:
         data.createCollection(GenCollection().withId(44).withName(QStringLiteral("44Note")).withRootAsParent().withNoteContent().selected(false));
         data.createCollection(GenCollection().withId(45).withName(QStringLiteral("45Note")).withParent(44).withNoteContent().selected(true));
 
-        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Tasks | Akonadi::StorageInterface::Notes,
-                                                                                         Akonadi::StorageInterface::Ptr(data.createStorage()),
+        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Ptr(data.createStorage()),
                                                                                          Akonadi::SerializerInterface::Ptr(new Akonadi::Serializer),
                                                                                          Akonadi::MonitorInterface::Ptr(data.createMonitor())));
 
         Domain::QueryResult<Domain::DataSource::Ptr>::Ptr result = queries->findAllSelected();
         TestHelpers::waitForEmptyJobQueue();
-        QCOMPARE(result->data().size(), 2);
+        QCOMPARE(result->data().size(), 1);
 
         // WHEN
         data.removeCollection(Akonadi::Collection(43));
@@ -708,8 +584,7 @@ private slots:
         data.createCollection(GenCollection().withId(44).withName(QStringLiteral("44Note")).withRootAsParent().withNoteContent().selected(false));
         data.createCollection(GenCollection().withId(45).withName(QStringLiteral("45Note")).withParent(44).withNoteContent().selected(true));
 
-        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Tasks | Akonadi::StorageInterface::Notes,
-                                                                                         Akonadi::StorageInterface::Ptr(data.createStorage()),
+        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Ptr(data.createStorage()),
                                                                                          Akonadi::SerializerInterface::Ptr(new Akonadi::Serializer),
                                                                                          Akonadi::MonitorInterface::Ptr(data.createMonitor())));
 
@@ -720,7 +595,7 @@ private slots:
                                           replaceHandlerCalled = true;
                                       });
         TestHelpers::waitForEmptyJobQueue();
-        QCOMPARE(result->data().size(), 2);
+        QCOMPARE(result->data().size(), 1);
 
         // WHEN
         data.modifyCollection(GenCollection(data.collection(43)).withName(QStringLiteral("43TaskBis")));
@@ -728,9 +603,8 @@ private slots:
         TestHelpers::waitForEmptyJobQueue();
 
         // THEN
-        QCOMPARE(result->data().size(), 2);
+        QCOMPARE(result->data().size(), 1);
         QCOMPARE(result->data().at(0)->name(), QStringLiteral("42Task » 43TaskBis"));
-        QCOMPARE(result->data().at(1)->name(), QStringLiteral("44Note » 45NoteBis"));
         QVERIFY(replaceHandlerCalled);
     }
 
@@ -770,8 +644,7 @@ private slots:
         data.createCollection(GenCollection().withId(44).withName(QStringLiteral("44Note")).withRootAsParent().withNoteContent().selected(false));
         data.createCollection(GenCollection().withId(45).withName(QStringLiteral("45Note")).withParent(44).withNoteContent().selected(true));
 
-        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Tasks | Akonadi::StorageInterface::Notes,
-                                                                                         Akonadi::StorageInterface::Ptr(data.createStorage()),
+        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Ptr(data.createStorage()),
                                                                                          Akonadi::SerializerInterface::Ptr(new Akonadi::Serializer),
                                                                                          Akonadi::MonitorInterface::Ptr(data.createMonitor())));
         QFETCH(int, colErrorCode);
@@ -812,8 +685,7 @@ private slots:
 
         // WHEN
         auto serializer = Akonadi::Serializer::Ptr(new Akonadi::Serializer);
-        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Tasks | Akonadi::StorageInterface::Notes,
-                                                                                         Akonadi::StorageInterface::Ptr(data.createStorage()),
+        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Ptr(data.createStorage()),
                                                                                          serializer,
                                                                                          Akonadi::MonitorInterface::Ptr(data.createMonitor())));
         Domain::DataSource::Ptr dataSource1 = serializer->createDataSourceFromCollection(data.collection(42), Akonadi::SerializerInterface::BaseName);
@@ -860,8 +732,7 @@ private slots:
 
         // WHEN
         auto serializer = Akonadi::Serializer::Ptr(new Akonadi::Serializer);
-        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Tasks | Akonadi::StorageInterface::Notes,
-                                                                                         Akonadi::StorageInterface::Ptr(data.createStorage()),
+        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Ptr(data.createStorage()),
                                                                                          serializer,
                                                                                          Akonadi::MonitorInterface::Ptr(data.createMonitor())));
         Domain::DataSource::Ptr dataSource = serializer->createDataSourceFromCollection(data.collection(42), Akonadi::SerializerInterface::BaseName);
@@ -883,8 +754,7 @@ private slots:
         data.createCollection(GenCollection().withId(42).withRootAsParent().withTaskContent());
 
         auto serializer = Akonadi::Serializer::Ptr(new Akonadi::Serializer);
-        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Tasks | Akonadi::StorageInterface::Notes,
-                                                                                         Akonadi::StorageInterface::Ptr(data.createStorage()),
+        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Ptr(data.createStorage()),
                                                                                          serializer,
                                                                                          Akonadi::MonitorInterface::Ptr(data.createMonitor())));
         Domain::DataSource::Ptr dataSource = serializer->createDataSourceFromCollection(data.collection(42), Akonadi::SerializerInterface::BaseName);
@@ -915,8 +785,7 @@ private slots:
         data.createItem(GenTodo().withId(44).withParent(42).withTitle(QStringLiteral("44")).asProject());
 
         auto serializer = Akonadi::Serializer::Ptr(new Akonadi::Serializer);
-        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Tasks | Akonadi::StorageInterface::Notes,
-                                                                                         Akonadi::StorageInterface::Ptr(data.createStorage()),
+        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Ptr(data.createStorage()),
                                                                                          serializer,
                                                                                          Akonadi::MonitorInterface::Ptr(data.createMonitor())));
         Domain::DataSource::Ptr dataSource = serializer->createDataSourceFromCollection(data.collection(42), Akonadi::SerializerInterface::BaseName);
@@ -947,8 +816,7 @@ private slots:
         data.createItem(GenTodo().withId(44).withParent(42).withTitle(QStringLiteral("44")).asProject());
 
         auto serializer = Akonadi::Serializer::Ptr(new Akonadi::Serializer);
-        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Tasks | Akonadi::StorageInterface::Notes,
-                                                                                         Akonadi::StorageInterface::Ptr(data.createStorage()),
+        QScopedPointer<Domain::DataSourceQueries> queries(new Akonadi::DataSourceQueries(Akonadi::StorageInterface::Ptr(data.createStorage()),
                                                                                          serializer,
                                                                                          Akonadi::MonitorInterface::Ptr(data.createMonitor())));
         Domain::DataSource::Ptr dataSource = serializer->createDataSourceFromCollection(data.collection(42), Akonadi::SerializerInterface::BaseName);
