@@ -28,15 +28,11 @@
 #include <functional>
 
 #include <KCalCore/Todo>
-#include <KMime/Message>
-#include <Akonadi/Notes/NoteUtils>
 
 #include "akonadi/akonadiserializer.h"
 
 #include "testlib/akonadifakedata.h"
 #include "testlib/gencollection.h"
-#include "testlib/gennote.h"
-#include "testlib/gentag.h"
 #include "testlib/gentodo.h"
 #include "testlib/testhelpers.h"
 
@@ -44,19 +40,11 @@ using namespace Testlib;
 
 using namespace std::placeholders;
 
-Q_DECLARE_METATYPE(Akonadi::StorageInterface::FetchContentTypes)
-
 static QString titleFromItem(const Akonadi::Item &item)
 {
     if (item.hasPayload<KCalCore::Todo::Ptr>()) {
         const auto todo = item.payload<KCalCore::Todo::Ptr>();
         return todo->summary();
-
-    } else if (item.hasPayload<KMime::Message::Ptr>()) {
-        const auto message = item.payload<KMime::Message::Ptr>();
-        const Akonadi::NoteUtils::NoteMessageWrapper note(message);
-        return note.title();
-
     } else {
         return QString();
     }
@@ -83,17 +71,7 @@ private:
     }
 
 private slots:
-    void shouldFetchAllCollectionsForType_data()
-    {
-        QTest::addColumn<Akonadi::StorageInterface::FetchContentTypes>("contentTypes");
-
-        QTest::newRow("task collections only") << Akonadi::StorageInterface::FetchContentTypes(Akonadi::StorageInterface::Tasks);
-        QTest::newRow("note collections only") << Akonadi::StorageInterface::FetchContentTypes(Akonadi::StorageInterface::Notes);
-        QTest::newRow("task and note collections only") << (Akonadi::StorageInterface::Tasks | Akonadi::StorageInterface::Notes);
-        QTest::newRow("all collections") << Akonadi::StorageInterface::FetchContentTypes(Akonadi::StorageInterface::AllContent);
-    }
-
-    void shouldFetchAllCollectionsForType()
+    void shouldFetchAllCollections()
     {
         // GIVEN
         auto data = AkonadiFakeData();
@@ -122,8 +100,7 @@ private slots:
         };
 
         // WHEN
-        QFETCH(Akonadi::StorageInterface::FetchContentTypes, contentTypes);
-        auto fetch = helpers->fetchAllCollections(contentTypes);
+        auto fetch = helpers->fetchAllCollections();
         fetch(add);
         TestHelpers::waitForEmptyJobQueue();
 
@@ -135,18 +112,7 @@ private slots:
 
         // THEN
         auto expected = QStringList();
-
-        if (contentTypes == Akonadi::StorageInterface::AllContent) {
-            expected << QStringLiteral("42") << QStringLiteral("45") << QStringLiteral("48") << QStringLiteral("51");
-        }
-
-        if ((contentTypes & Akonadi::StorageInterface::Tasks) || contentTypes == Akonadi::StorageInterface::AllContent) {
-            expected << QStringLiteral("43") << QStringLiteral("46") << QStringLiteral("49") << QStringLiteral("52");
-        }
-
-        if ((contentTypes & Akonadi::StorageInterface::Notes) || contentTypes == Akonadi::StorageInterface::AllContent) {
-            expected << QStringLiteral("44") << QStringLiteral("47") << QStringLiteral("50") << QStringLiteral("53");
-        }
+        expected << QStringLiteral("43") << QStringLiteral("46") << QStringLiteral("49") << QStringLiteral("52");
 
         expected.sort();
         QCOMPARE(result, expected);
@@ -166,49 +132,17 @@ private slots:
         QCOMPARE(result, expected);
     }
 
-    void shouldFetchCollectionsForRootAndType_data()
+    void shouldFetchCollectionsForRoot_data()
     {
         QTest::addColumn<Akonadi::Collection>("root");
-        QTest::addColumn<Akonadi::StorageInterface::FetchContentTypes>("contentTypes");
 
-        QTest::newRow("task collections only from root") << Akonadi::Collection::root()
-                                                         << Akonadi::StorageInterface::FetchContentTypes(Akonadi::StorageInterface::Tasks);
-        QTest::newRow("note collections only from root") << Akonadi::Collection::root()
-                                                         << Akonadi::StorageInterface::FetchContentTypes(Akonadi::StorageInterface::Notes);
-        QTest::newRow("task and note collections only from root") << Akonadi::Collection::root()
-                                                                  << (Akonadi::StorageInterface::Tasks | Akonadi::StorageInterface::Notes);
-        QTest::newRow("all collections from root") << Akonadi::Collection::root()
-                                                   << Akonadi::StorageInterface::FetchContentTypes(Akonadi::StorageInterface::AllContent);
-
-        QTest::newRow("task collections only from 'all branch'") << Akonadi::Collection(42)
-                                                                 << Akonadi::StorageInterface::FetchContentTypes(Akonadi::StorageInterface::Tasks);
-        QTest::newRow("note collections only from 'all branch'") << Akonadi::Collection(42)
-                                                                 << Akonadi::StorageInterface::FetchContentTypes(Akonadi::StorageInterface::Notes);
-        QTest::newRow("task and note collections only from 'all branch'") << Akonadi::Collection(42)
-                                                                          << (Akonadi::StorageInterface::Tasks | Akonadi::StorageInterface::Notes);
-        QTest::newRow("all collections from 'all branch'") << Akonadi::Collection(42)
-                                                           << Akonadi::StorageInterface::FetchContentTypes(Akonadi::StorageInterface::AllContent);
-
-        QTest::newRow("task collections only from 'task branch'") << Akonadi::Collection(43)
-                                                                  << Akonadi::StorageInterface::FetchContentTypes(Akonadi::StorageInterface::Tasks);
-        QTest::newRow("note collections only from 'task branch'") << Akonadi::Collection(43)
-                                                                  << Akonadi::StorageInterface::FetchContentTypes(Akonadi::StorageInterface::Notes);
-        QTest::newRow("task and note collections only from 'task branch'") << Akonadi::Collection(43)
-                                                                           << (Akonadi::StorageInterface::Tasks | Akonadi::StorageInterface::Notes);
-        QTest::newRow("all collections from 'task branch'") << Akonadi::Collection(43)
-                                                            << Akonadi::StorageInterface::FetchContentTypes(Akonadi::StorageInterface::AllContent);
-
-        QTest::newRow("task collections only from 'note branch'") << Akonadi::Collection(44)
-                                                                  << Akonadi::StorageInterface::FetchContentTypes(Akonadi::StorageInterface::Tasks);
-        QTest::newRow("note collections only from 'note branch'") << Akonadi::Collection(44)
-                                                                  << Akonadi::StorageInterface::FetchContentTypes(Akonadi::StorageInterface::Notes);
-        QTest::newRow("task and note collections only from 'note branch'") << Akonadi::Collection(44)
-                                                                           << (Akonadi::StorageInterface::Tasks | Akonadi::StorageInterface::Notes);
-        QTest::newRow("all collections from 'note branch'") << Akonadi::Collection(44)
-                                                            << Akonadi::StorageInterface::FetchContentTypes(Akonadi::StorageInterface::AllContent);
+        QTest::newRow("all collections from root") << Akonadi::Collection::root();
+        QTest::newRow("all collections from 'all branch'") << Akonadi::Collection(42);
+        QTest::newRow("all collections from 'task branch'") << Akonadi::Collection(43);
+        QTest::newRow("all collections from 'note branch'") << Akonadi::Collection(44);
     }
 
-    void shouldFetchCollectionsForRootAndType()
+    void shouldFetchCollectionsForRoot()
     {
         // GIVEN
         auto data = AkonadiFakeData();
@@ -238,8 +172,7 @@ private slots:
 
         // WHEN
         QFETCH(Akonadi::Collection, root);
-        QFETCH(Akonadi::StorageInterface::FetchContentTypes, contentTypes);
-        auto fetch = helpers->fetchCollections(root, contentTypes);
+        auto fetch = helpers->fetchCollections(root);
         fetch(add);
         TestHelpers::waitForEmptyJobQueue();
 
@@ -261,17 +194,7 @@ private slots:
                                 : -1;
             QVERIFY(baseId > 0);
 
-            if (contentTypes == Akonadi::StorageInterface::AllContent) {
-                expected << QString::number(baseId);
-            }
-
-            if ((contentTypes & Akonadi::StorageInterface::Tasks) || contentTypes == Akonadi::StorageInterface::AllContent) {
-                expected << QString::number(baseId + 1);
-            }
-
-            if ((contentTypes & Akonadi::StorageInterface::Notes) || contentTypes == Akonadi::StorageInterface::AllContent) {
-                expected << QString::number(baseId + 2);
-            }
+            expected << QString::number(baseId + 1);
         }
 
         expected.sort();
@@ -292,17 +215,7 @@ private slots:
         QCOMPARE(result, expected);
     }
 
-    void shouldFetchItemsByContentTypes_data()
-    {
-        QTest::addColumn<Akonadi::StorageInterface::FetchContentTypes>("contentTypes");
-
-        QTest::newRow("task collections only") << Akonadi::StorageInterface::FetchContentTypes(Akonadi::StorageInterface::Tasks);
-        QTest::newRow("note collections only") << Akonadi::StorageInterface::FetchContentTypes(Akonadi::StorageInterface::Notes);
-        QTest::newRow("task and note collections only") << (Akonadi::StorageInterface::Tasks | Akonadi::StorageInterface::Notes);
-        QTest::newRow("all collections") << Akonadi::StorageInterface::FetchContentTypes(Akonadi::StorageInterface::AllContent);
-    }
-
-    void shouldFetchItemsByContentTypes()
+    void shouldFetchItems()
     {
         // GIVEN
         auto data = AkonadiFakeData();
@@ -321,11 +234,11 @@ private slots:
         // One task in the first collection
         data.createItem(GenTodo().withId(42).withParent(42).withTitle(QStringLiteral("42")));
 
-        // Two items (tasks or notes) in all the other collections
+        // Two tasks in all the other collections
         data.createItem(GenTodo().withId(43).withParent(43).withTitle(QStringLiteral("43")));
         data.createItem(GenTodo().withId(44).withParent(43).withTitle(QStringLiteral("44")));
-        data.createItem(GenNote().withId(45).withParent(44).withTitle(QStringLiteral("45")));
-        data.createItem(GenNote().withId(46).withParent(44).withTitle(QStringLiteral("46")));
+        data.createItem(GenTodo().withId(45).withParent(44).withTitle(QStringLiteral("45")));
+        data.createItem(GenTodo().withId(46).withParent(44).withTitle(QStringLiteral("46")));
         data.createItem(GenTodo().withId(47).withParent(45).withTitle(QStringLiteral("47")));
         data.createItem(GenTodo().withId(48).withParent(45).withTitle(QStringLiteral("48")));
 
@@ -336,8 +249,7 @@ private slots:
         };
 
         // WHEN
-        QFETCH(Akonadi::StorageInterface::FetchContentTypes, contentTypes);
-        auto fetch = helpers->fetchItems(contentTypes);
+        auto fetch = helpers->fetchItems();
         fetch(add);
         TestHelpers::waitForEmptyJobQueue();
 
@@ -349,15 +261,7 @@ private slots:
 
         // THEN
         auto expected = QStringList();
-
-        if ((contentTypes & Akonadi::StorageInterface::Tasks) || contentTypes == Akonadi::StorageInterface::AllContent) {
-            expected << QStringLiteral("43") << QStringLiteral("44") << QStringLiteral("47") << QStringLiteral("48");
-        }
-
-        if ((contentTypes & Akonadi::StorageInterface::Notes) || contentTypes == Akonadi::StorageInterface::AllContent) {
-            expected << QStringLiteral("45") << QStringLiteral("46");
-        }
-
+        expected << QStringLiteral("43") << QStringLiteral("44") << QStringLiteral("47") << QStringLiteral("48");
         expected.sort();
         QCOMPARE(result, expected);
 
@@ -449,15 +353,20 @@ private slots:
         QCOMPARE(result, expected);
     }
 
-    void shouldFetchItemsByTag_data()
+    void shouldFetchItemsForContext_data()
     {
-        QTest::addColumn<Akonadi::Tag>("tag");
+        QTest::addColumn<Domain::Context::Ptr>("context");
 
-        QTest::newRow("first tag") << Akonadi::Tag(42);
-        QTest::newRow("second tag") << Akonadi::Tag(43);
+        auto context1 = Domain::Context::Ptr::create();
+        context1->setProperty("todoUid", "ctx-42");
+        auto context2 = Domain::Context::Ptr::create();
+        context2->setProperty("todoUid", "ctx-43");
+
+        QTest::newRow("first") << context1;
+        QTest::newRow("second") << context2;
     }
 
-    void shouldFetchItemsByTag()
+    void shouldFetchItemsForContext()
     {
         // GIVEN
         auto data = AkonadiFakeData();
@@ -467,20 +376,20 @@ private slots:
         data.createCollection(GenCollection().withId(42).withRootAsParent().withName(QStringLiteral("42")).withTaskContent());
         data.createCollection(GenCollection().withId(43).withRootAsParent().withName(QStringLiteral("43")).withTaskContent());
 
-        // Two tags
-        data.createTag(GenTag().withId(42));
-        data.createTag(GenTag().withId(43));
+        // Two contexts
+        data.createItem(GenTodo().withId(142).withUid("ctx-42").asContext());
+        data.createItem(GenTodo().withId(143).withUid("ctx-43").asContext());
 
-        // Four items in each collection, one with no tag, one with the first tag,
-        // one with the second tag, last one with both tags
-        data.createItem(GenTodo().withId(42).withParent(42).withTags({}).withTitle(QStringLiteral("42")));
-        data.createItem(GenTodo().withId(43).withParent(42).withTags({42}).withTitle(QStringLiteral("43")));
-        data.createItem(GenTodo().withId(44).withParent(42).withTags({43}).withTitle(QStringLiteral("44")));
-        data.createItem(GenTodo().withId(45).withParent(42).withTags({42, 43}).withTitle(QStringLiteral("45")));
-        data.createItem(GenTodo().withId(46).withParent(43).withTags({}).withTitle(QStringLiteral("46")));
-        data.createItem(GenTodo().withId(47).withParent(43).withTags({42}).withTitle(QStringLiteral("47")));
-        data.createItem(GenTodo().withId(48).withParent(43).withTags({43}).withTitle(QStringLiteral("48")));
-        data.createItem(GenTodo().withId(49).withParent(43).withTags({42, 43}).withTitle(QStringLiteral("49")));
+        // Four items in each collection, one with no context, one with the first context,
+        // one with the second context, last one with both contexts
+        data.createItem(GenTodo().withId(42).withParent(42).withContexts({}).withTitle(QStringLiteral("42")));
+        data.createItem(GenTodo().withId(43).withParent(42).withContexts({"ctx-42"}).withTitle(QStringLiteral("43")));
+        data.createItem(GenTodo().withId(44).withParent(42).withContexts({"ctx-43"}).withTitle(QStringLiteral("44")));
+        data.createItem(GenTodo().withId(45).withParent(42).withContexts({"ctx-42", "ctx-43"}).withTitle(QStringLiteral("45")));
+        data.createItem(GenTodo().withId(46).withParent(43).withContexts({}).withTitle(QStringLiteral("46")));
+        data.createItem(GenTodo().withId(47).withParent(43).withContexts({"ctx-42"}).withTitle(QStringLiteral("47")));
+        data.createItem(GenTodo().withId(48).withParent(43).withContexts({"ctx-43"}).withTitle(QStringLiteral("48")));
+        data.createItem(GenTodo().withId(49).withParent(43).withContexts({"ctx-42", "ctx-43"}).withTitle(QStringLiteral("49")));
 
         // The list which will be filled by the fetch function
         auto items = Akonadi::Item::List();
@@ -489,8 +398,8 @@ private slots:
         };
 
         // WHEN
-        QFETCH(Akonadi::Tag, tag);
-        auto fetch = helpers->fetchItems(tag);
+        QFETCH(Domain::Context::Ptr, context);
+        auto fetch = helpers->fetchItemsForContext(context);
         fetch(add);
         TestHelpers::waitForEmptyJobQueue();
 
@@ -503,14 +412,10 @@ private slots:
         // THEN
         auto expected = QStringList();
 
-        switch (tag.id()) {
-        case 42:
+        if (context->property("todoUid") == "ctx-42")
             expected << QStringLiteral("43") << QStringLiteral("45") << QStringLiteral("47") << QStringLiteral("49");
-            break;
-        case 43:
+        else if (context->property("todoUid") == "ctx-43")
             expected << QStringLiteral("44") << QStringLiteral("45") << QStringLiteral("48") << QStringLiteral("49");
-            break;
-        }
         QVERIFY(!expected.isEmpty());
 
         expected.sort();
@@ -554,10 +459,10 @@ private slots:
         data.createItem(GenTodo().withId(43).withParent(42).withTitle(QStringLiteral("43")));
         data.createItem(GenTodo().withId(44).withParent(42).withTitle(QStringLiteral("44")));
         data.createItem(GenTodo().withId(45).withParent(42).withTitle(QStringLiteral("45")));
-        data.createItem(GenNote().withId(46).withParent(43).withTitle(QStringLiteral("46")));
-        data.createItem(GenNote().withId(47).withParent(43).withTitle(QStringLiteral("47")));
-        data.createItem(GenNote().withId(48).withParent(43).withTitle(QStringLiteral("48")));
-        data.createItem(GenNote().withId(49).withParent(43).withTitle(QStringLiteral("49")));
+        data.createItem(GenTodo().withId(46).withParent(43).withTitle(QStringLiteral("46")));
+        data.createItem(GenTodo().withId(47).withParent(43).withTitle(QStringLiteral("47")));
+        data.createItem(GenTodo().withId(48).withParent(43).withTitle(QStringLiteral("48")));
+        data.createItem(GenTodo().withId(49).withParent(43).withTitle(QStringLiteral("49")));
 
         // The list which will be filled by the fetch function
         auto items = Akonadi::Item::List();
@@ -607,53 +512,6 @@ private slots:
         result.sort();
         QCOMPARE(result, expected);
     }
-
-    void shouldFetchTags()
-    {
-        // GIVEN
-        auto data = AkonadiFakeData();
-        auto helpers = createHelpers(data);
-
-        // Two tags (one plain, one context)
-        data.createTag(GenTag().withId(42).withName(QStringLiteral("42")).asPlain());
-        data.createTag(GenTag().withId(43).withName(QStringLiteral("43")).asContext());
-
-        // The list which will be filled by the fetch function
-        auto tags = Akonadi::Tag::List();
-        auto add = [&tags] (const Akonadi::Tag &tag) {
-            tags.append(tag);
-        };
-
-        // WHEN
-        auto fetch = helpers->fetchTags();
-        fetch(add);
-        TestHelpers::waitForEmptyJobQueue();
-
-        auto result = QStringList();
-        std::transform(tags.constBegin(), tags.constEnd(),
-                       std::back_inserter(result),
-                       std::bind(&Akonadi::Tag::name, _1));
-        result.sort();
-
-        // THEN
-        auto expected = QStringList({"42", "43"});
-        expected.sort();
-        QCOMPARE(result, expected);
-
-        // WHEN (should not crash when the helpers object is deleted)
-        helpers.clear();
-        tags.clear();
-        fetch(add);
-        TestHelpers::waitForEmptyJobQueue();
-
-        // THEN
-        result.clear();
-        std::transform(tags.constBegin(), tags.constEnd(),
-                       std::back_inserter(result),
-                       std::bind(&Akonadi::Tag::name, _1));
-        result.sort();
-        QCOMPARE(result, expected);
-    }
 };
 
 ZANSHIN_TEST_MAIN(AkonadiLiveQueryHelpersTest)
