@@ -35,7 +35,6 @@
 #include "testlib/gencollection.h"
 #include "testlib/gentodo.h"
 
-#include "akonadi/akonadimessaginginterface.h"
 #include "akonadi/akonaditaskrepository.h"
 #include "akonadi/akonadiserializer.h"
 #include "akonadi/akonadistorageinterface.h"
@@ -50,10 +49,9 @@ class AkonadiTaskRepositoryTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit AkonadiTaskRepositoryTest(QObject *parent = Q_NULLPTR)
+    explicit AkonadiTaskRepositoryTest(QObject *parent = nullptr)
         : QObject(parent)
     {
-        qRegisterMetaType<Domain::Task::Delegate>();
     }
 
 private slots:
@@ -73,7 +71,7 @@ private slots:
 
         // Storage mock returning the create job
         Utils::MockObject<Akonadi::StorageInterface> storageMock;
-        storageMock(&Akonadi::StorageInterface::defaultTaskCollection).when().thenReturn(col);
+        storageMock(&Akonadi::StorageInterface::defaultCollection).when().thenReturn(col);
         storageMock(&Akonadi::StorageInterface::createItem).when(item, col)
                                                            .thenReturn(itemCreateJob);
 
@@ -83,13 +81,12 @@ private slots:
 
         // WHEN
         QScopedPointer<Akonadi::TaskRepository> repository(new Akonadi::TaskRepository(storageMock.getInstance(),
-                                                                                       serializerMock.getInstance(),
-                                                                                       Akonadi::MessagingInterface::Ptr()));
+                                                                                       serializerMock.getInstance()));
         repository->create(task)->exec();
 
         // THEN
         QVERIFY(serializerMock(&Akonadi::SerializerInterface::createItemFromTask).when(task).exactly(1));
-        QVERIFY(storageMock(&Akonadi::StorageInterface::defaultTaskCollection).when().exactly(1));
+        QVERIFY(storageMock(&Akonadi::StorageInterface::defaultCollection).when().exactly(1));
         QVERIFY(storageMock(&Akonadi::StorageInterface::createItem).when(item, col).exactly(1));
     }
 
@@ -98,11 +95,11 @@ private slots:
         // GIVEN
 
         // A few collections
-        auto col1 = Akonadi::Collection(42);
+        auto col1 = Akonadi::Collection(GenCollection().withId(42).withRootAsParent().withTaskContent());
         col1.setRights(Akonadi::Collection::ReadOnly);
-        auto col2 = Akonadi::Collection(43);
+        auto col2 = Akonadi::Collection(GenCollection().withId(43).withRootAsParent().withTaskContent());
         col2.setRights(Akonadi::Collection::CanCreateItem);
-        auto col3 = Akonadi::Collection(44);
+        auto col3 = Akonadi::Collection(GenCollection().withId(44).withRootAsParent().withTaskContent());
         col3.setRights(Akonadi::Collection::CanCreateItem
                      | Akonadi::Collection::CanChangeItem
                      | Akonadi::Collection::CanDeleteItem);
@@ -118,10 +115,9 @@ private slots:
 
         // Storage mock returning the create job and with no default collection
         Utils::MockObject<Akonadi::StorageInterface> storageMock;
-        storageMock(&Akonadi::StorageInterface::defaultTaskCollection).when().thenReturn(Akonadi::Collection());
+        storageMock(&Akonadi::StorageInterface::defaultCollection).when().thenReturn(Akonadi::Collection());
         storageMock(&Akonadi::StorageInterface::fetchCollections).when(Akonadi::Collection::root(),
-                                                                       Akonadi::StorageInterface::Recursive,
-                                                                       Akonadi::StorageInterface::Tasks)
+                                                                       Akonadi::StorageInterface::Recursive)
                                                                  .thenReturn(collectionFetchJob);
         storageMock(&Akonadi::StorageInterface::createItem).when(item, col3)
                                                            .thenReturn(itemCreateJob);
@@ -132,13 +128,12 @@ private slots:
 
         // WHEN
         QScopedPointer<Akonadi::TaskRepository> repository(new Akonadi::TaskRepository(storageMock.getInstance(),
-                                                                                       serializerMock.getInstance(),
-                                                                                       Akonadi::MessagingInterface::Ptr()));
+                                                                                       serializerMock.getInstance()));
         repository->create(task)->exec();
 
         // THEN
         QVERIFY(serializerMock(&Akonadi::SerializerInterface::createItemFromTask).when(task).exactly(1));
-        QVERIFY(storageMock(&Akonadi::StorageInterface::defaultTaskCollection).when().exactly(1));
+        QVERIFY(storageMock(&Akonadi::StorageInterface::defaultCollection).when().exactly(1));
         QVERIFY(storageMock(&Akonadi::StorageInterface::createItem).when(item, col3).exactly(1));
     }
 
@@ -147,11 +142,11 @@ private slots:
         // GIVEN
 
         // A few collections
-        auto col1 = Akonadi::Collection(42);
+        auto col1 = Akonadi::Collection(GenCollection().withId(42).withRootAsParent().withTaskContent());
         col1.setRights(Akonadi::Collection::ReadOnly);
-        auto col2 = Akonadi::Collection(43);
-        col2.setRights(Akonadi::Collection::ReadOnly);
-        auto col3 = Akonadi::Collection(44);
+        auto col2 = Akonadi::Collection(GenCollection().withId(43).withRootAsParent().withTaskContent());
+        col2.setRights(Akonadi::Collection::CanCreateItem);
+        auto col3 = Akonadi::Collection(GenCollection().withId(44).withRootAsParent().withTaskContent());
         col3.setRights(Akonadi::Collection::ReadOnly);
         auto collectionFetchJob = new Testlib::AkonadiFakeCollectionFetchJob;
         collectionFetchJob->setCollections(Akonadi::Collection::List() << col1 << col2 << col3);
@@ -162,10 +157,9 @@ private slots:
 
         // Storage mock returning the create job and with no default collection
         Utils::MockObject<Akonadi::StorageInterface> storageMock;
-        storageMock(&Akonadi::StorageInterface::defaultTaskCollection).when().thenReturn(Akonadi::Collection());
+        storageMock(&Akonadi::StorageInterface::defaultCollection).when().thenReturn(Akonadi::Collection());
         storageMock(&Akonadi::StorageInterface::fetchCollections).when(Akonadi::Collection::root(),
-                                                                       Akonadi::StorageInterface::Recursive,
-                                                                       Akonadi::StorageInterface::Tasks)
+                                                                       Akonadi::StorageInterface::Recursive)
                                                                  .thenReturn(collectionFetchJob);
 
         // Serializer mock returning the item for the task
@@ -174,14 +168,13 @@ private slots:
 
         // WHEN
         QScopedPointer<Akonadi::TaskRepository> repository(new Akonadi::TaskRepository(storageMock.getInstance(),
-                                                                                       serializerMock.getInstance(),
-                                                                                       Akonadi::MessagingInterface::Ptr()));
+                                                                                       serializerMock.getInstance()));
         auto job = repository->create(task);
         job->exec();
 
         // THEN
         QVERIFY(serializerMock(&Akonadi::SerializerInterface::createItemFromTask).when(task).exactly(1));
-        QVERIFY(storageMock(&Akonadi::StorageInterface::defaultTaskCollection).when().exactly(1));
+        QVERIFY(storageMock(&Akonadi::StorageInterface::defaultCollection).when().exactly(1));
         QVERIFY(job->error());
         QVERIFY(!job->errorText().isEmpty());
     }
@@ -216,8 +209,7 @@ private slots:
 
         // WHEN
         QScopedPointer<Akonadi::TaskRepository> repository(new Akonadi::TaskRepository(storageMock.getInstance(),
-                                                                                       serializerMock.getInstance(),
-                                                                                       Akonadi::MessagingInterface::Ptr()));
+                                                                                       serializerMock.getInstance()));
         repository->createChild(child, parent)->exec();
 
         // THEN
@@ -257,8 +249,7 @@ private slots:
 
         // WHEN
         QScopedPointer<Akonadi::TaskRepository> repository(new Akonadi::TaskRepository(storageMock.getInstance(),
-                                                                                       serializerMock.getInstance(),
-                                                                                       Akonadi::MessagingInterface::Ptr()));
+                                                                                       serializerMock.getInstance()));
         repository->createInProject(task, project)->exec();
 
         // THEN
@@ -271,12 +262,11 @@ private slots:
     void shouldCreateNewItemsInContext()
     {
         // GIVEN
-        // a tag
-        Akonadi::Tag tag;
-        tag.setName(QStringLiteral("tag42"));
-        tag.setId(42);
+        // a context item
+        Akonadi::Item contextItem;
+        contextItem.setId(42);
 
-        // the context related to the tag
+        // the context related to the item
         auto context = Domain::Context::Ptr::create();
 
         // a default collection
@@ -292,28 +282,27 @@ private slots:
         // serializer mock returning the item for the task
         Utils::MockObject<Akonadi::SerializerInterface> serializerMock;
 
-        serializerMock(&Akonadi::SerializerInterface::createTagFromContext).when(context).thenReturn(tag);
         serializerMock(&Akonadi::SerializerInterface::createItemFromTask).when(task).thenReturn(taskItem);
+        serializerMock(&Akonadi::SerializerInterface::addContextToTask).when(context, taskItem).thenReturn();
 
         // Storage mock returning the create job
         Utils::MockObject<Akonadi::StorageInterface> storageMock;
 
-        storageMock(&Akonadi::StorageInterface::defaultTaskCollection).when().thenReturn(defaultCollection);
+        storageMock(&Akonadi::StorageInterface::defaultCollection).when().thenReturn(defaultCollection);
         storageMock(&Akonadi::StorageInterface::createItem).when(taskItem, defaultCollection).thenReturn(itemCreateJob);
 
         // WHEN
         QScopedPointer<Akonadi::TaskRepository> repository(new Akonadi::TaskRepository(storageMock.getInstance(),
-                                                                                       serializerMock.getInstance(),
-                                                                                       Akonadi::MessagingInterface::Ptr()));
+                                                                                       serializerMock.getInstance()));
 
         repository->createInContext(task, context)->exec();
 
         // THEN
 
         QVERIFY(serializerMock(&Akonadi::SerializerInterface::createItemFromTask).when(task).exactly(1));
-        QVERIFY(serializerMock(&Akonadi::SerializerInterface::createTagFromContext).when(context).exactly(1));
+        QVERIFY(serializerMock(&Akonadi::SerializerInterface::addContextToTask).when(context, taskItem).exactly(1));
 
-        QVERIFY(storageMock(&Akonadi::StorageInterface::defaultTaskCollection).when().exactly(1));
+        QVERIFY(storageMock(&Akonadi::StorageInterface::defaultCollection).when().exactly(1));
         QVERIFY(storageMock(&Akonadi::StorageInterface::createItem).when(taskItem, defaultCollection).exactly(1));
     }
 
@@ -333,7 +322,7 @@ private slots:
 
         // Storage mock returning the create job
         Utils::MockObject<Akonadi::StorageInterface> storageMock;
-        storageMock(&Akonadi::StorageInterface::updateItem).when(item, Q_NULLPTR)
+        storageMock(&Akonadi::StorageInterface::updateItem).when(item, nullptr)
                                                            .thenReturn(itemModifyJob);
 
         // Serializer mock returning the item for the task
@@ -342,13 +331,12 @@ private slots:
 
         // WHEN
         QScopedPointer<Akonadi::TaskRepository> repository(new Akonadi::TaskRepository(storageMock.getInstance(),
-                                                                                       serializerMock.getInstance(),
-                                                                                       Akonadi::MessagingInterface::Ptr()));
+                                                                                       serializerMock.getInstance()));
         repository->update(task)->exec();
 
         // THEN
         QVERIFY(serializerMock(&Akonadi::SerializerInterface::createItemFromTask).when(task).exactly(1));
-        QVERIFY(storageMock(&Akonadi::StorageInterface::updateItem).when(item, Q_NULLPTR).exactly(1));
+        QVERIFY(storageMock(&Akonadi::StorageInterface::updateItem).when(item, nullptr).exactly(1));
     }
 
     void shouldRemoveATask_data()
@@ -421,7 +409,7 @@ private slots:
                                                           .thenReturn(itemFetchJob1);
         storageMock(&Akonadi::StorageInterface::fetchItems).when(item.parentCollection())
                                                           .thenReturn(itemFetchJob2);
-        storageMock(&Akonadi::StorageInterface::removeItems).when(removedList, Q_NULLPTR)
+        storageMock(&Akonadi::StorageInterface::removeItems).when(removedList, nullptr)
                                                               .thenReturn(itemDeleteJob);
 
         // Serializer mock returning the item for the task
@@ -431,8 +419,7 @@ private slots:
 
         // WHEN
         QScopedPointer<Akonadi::TaskRepository> repository(new Akonadi::TaskRepository(storageMock.getInstance(),
-                                                                                       serializerMock.getInstance(),
-                                                                                       Akonadi::MessagingInterface::Ptr()));
+                                                                                       serializerMock.getInstance()));
         repository->remove(task)->exec();
 
         // THEN
@@ -441,7 +428,7 @@ private slots:
         if (itemFetchJobSucceeded) {
             QVERIFY(storageMock(&Akonadi::StorageInterface::fetchItems).when(item.parentCollection()).exactly(1));
             if (collectionItemsFetchJobSucceeded) {
-                QVERIFY(storageMock(&Akonadi::StorageInterface::removeItems).when(removedList, Q_NULLPTR).exactly(1));
+                QVERIFY(storageMock(&Akonadi::StorageInterface::removeItems).when(removedList, nullptr).exactly(1));
             }
         }
     }
@@ -473,20 +460,19 @@ private slots:
         Utils::MockObject<Akonadi::StorageInterface> storageMock;
         storageMock(&Akonadi::StorageInterface::fetchItem).when(item)
                                                           .thenReturn(itemFetchJob);
-        storageMock(&Akonadi::StorageInterface::updateItem).when(item, Q_NULLPTR)
+        storageMock(&Akonadi::StorageInterface::updateItem).when(item, nullptr)
                                                            .thenReturn(itemModifyJob);
 
         // WHEN
         QScopedPointer<Akonadi::TaskRepository> repository(new Akonadi::TaskRepository(storageMock.getInstance(),
-                                                                                       serializerMock.getInstance(),
-                                                                                       Akonadi::MessagingInterface::Ptr()));
+                                                                                       serializerMock.getInstance()));
         repository->promoteToProject(task)->exec();
 
         // THEN
         QVERIFY(serializerMock(&Akonadi::SerializerInterface::createItemFromTask).when(task).exactly(1));
         QVERIFY(serializerMock(&Akonadi::SerializerInterface::promoteItemToProject).when(item).exactly(1));
         QVERIFY(storageMock(&Akonadi::StorageInterface::fetchItem).when(item).exactly(1));
-        QVERIFY(storageMock(&Akonadi::StorageInterface::updateItem).when(item, Q_NULLPTR).exactly(1));
+        QVERIFY(storageMock(&Akonadi::StorageInterface::updateItem).when(item, nullptr).exactly(1));
     }
 
     void shouldAssociateATaskToAnother_data()
@@ -603,7 +589,7 @@ private slots:
             storageMock(&Akonadi::StorageInterface::moveItems).when(movedList, parentItem.parentCollection(), transactionJob)
                                                               .thenReturn(itemsMoveJob);
         } else {
-            storageMock(&Akonadi::StorageInterface::updateItem).when(childItem, Q_NULLPTR)
+            storageMock(&Akonadi::StorageInterface::updateItem).when(childItem, nullptr)
                                                                .thenReturn(itemModifyJob);
         }
 
@@ -614,8 +600,8 @@ private slots:
         serializerMock(&Akonadi::SerializerInterface::createTaskFromItem).when(childItem).thenReturn(child);
         serializerMock(&Akonadi::SerializerInterface::createTaskFromItem).when(parentItem).thenReturn(parent);
         serializerMock(&Akonadi::SerializerInterface::updateItemParent).when(childItem, parent).thenReturn();
-        serializerMock(&Akonadi::SerializerInterface::objectUid).when(parent).thenReturn(QStringLiteral("parent"));
-        serializerMock(&Akonadi::SerializerInterface::objectUid).when(child).thenReturn(QStringLiteral("child"));
+        serializerMock(&Akonadi::SerializerInterface::itemUid).when(parentItem).thenReturn(QStringLiteral("parent"));
+        serializerMock(&Akonadi::SerializerInterface::itemUid).when(childItem).thenReturn(QStringLiteral("child"));
         serializerMock(&Akonadi::SerializerInterface::relatedUidFromItem).when(parentItem).thenReturn(QString());
         serializerMock(&Akonadi::SerializerInterface::relatedUidFromItem).when(childItem).thenReturn(QString());
         if (execParentJob)
@@ -623,8 +609,7 @@ private slots:
 
         // WHEN
         QScopedPointer<Akonadi::TaskRepository> repository(new Akonadi::TaskRepository(storageMock.getInstance(),
-                                                                                       serializerMock.getInstance(),
-                                                                                       Akonadi::MessagingInterface::Ptr()));
+                                                                                       serializerMock.getInstance()));
         auto associateJob = repository->associate(parent, child);
         if (execJob)
             associateJob->exec();
@@ -639,7 +624,7 @@ private slots:
             QVERIFY(storageMock(&Akonadi::StorageInterface::fetchItems).when(parentItem.parentCollection()).exactly(1));
             if (execParentJob) {
                 if (parentItem.parentCollection().id() == childItem.parentCollection().id())
-                    QVERIFY(storageMock(&Akonadi::StorageInterface::updateItem).when(childItem, Q_NULLPTR).exactly(1));
+                    QVERIFY(storageMock(&Akonadi::StorageInterface::updateItem).when(childItem, nullptr).exactly(1));
                 else {
                     //QVERIFY(serializerMock(&Akonadi::SerializerInterface::filterDescendantItems).when(list, childItem).exactly(1));
                     QVERIFY(storageMock(&Akonadi::StorageInterface::fetchItems).when(childItem.parentCollection()).exactly(1));
@@ -675,8 +660,7 @@ private slots:
 
         auto monitor = Akonadi::MonitorInterface::Ptr(data.createMonitor());
         QScopedPointer<Akonadi::TaskRepository> repository(new Akonadi::TaskRepository(Akonadi::StorageInterface::Ptr(data.createStorage()),
-                                                                                       serializer,
-                                                                                       Akonadi::MessagingInterface::Ptr()));
+                                                                                       serializer));
         QSignalSpy spy(monitor.data(), &Akonadi::MonitorInterface::itemChanged);
 
         // WHEN
@@ -726,7 +710,7 @@ private slots:
 
         // Storage mock returning the delete job
         Utils::MockObject<Akonadi::StorageInterface> storageMock;
-        storageMock(&Akonadi::StorageInterface::updateItem).when(childItem, Q_NULLPTR)
+        storageMock(&Akonadi::StorageInterface::updateItem).when(childItem, nullptr)
                                                            .thenReturn(itemModifyJob);
         storageMock(&Akonadi::StorageInterface::fetchItem).when(childItem)
                                                           .thenReturn(itemFetchJob);
@@ -738,8 +722,7 @@ private slots:
 
         // WHEN
         QScopedPointer<Akonadi::TaskRepository> repository(new Akonadi::TaskRepository(storageMock.getInstance(),
-                                                                                       serializerMock.getInstance(),
-                                                                                       Akonadi::MessagingInterface::Ptr()));
+                                                                                       serializerMock.getInstance()));
         repository->dissociate(child)->exec();
 
         // THEN
@@ -747,7 +730,7 @@ private slots:
         QVERIFY(storageMock(&Akonadi::StorageInterface::fetchItem).when(childItem).exactly(1));
         if (!childJobFailed) {
             QVERIFY(serializerMock(&Akonadi::SerializerInterface::removeItemParent).when(childItem).exactly(1));;
-            QVERIFY(storageMock(&Akonadi::StorageInterface::updateItem).when(childItem, Q_NULLPTR).exactly(1));
+            QVERIFY(storageMock(&Akonadi::StorageInterface::updateItem).when(childItem, nullptr).exactly(1));
         }
     }
 
@@ -768,7 +751,7 @@ private slots:
 
         // Storage mock returning the delete job
         Utils::MockObject<Akonadi::StorageInterface> storageMock;
-        storageMock(&Akonadi::StorageInterface::updateItem).when(childItem, Q_NULLPTR)
+        storageMock(&Akonadi::StorageInterface::updateItem).when(childItem, nullptr)
                                                            .thenReturn(itemModifyJob);
         storageMock(&Akonadi::StorageInterface::fetchItem).when(childItem)
                                                           .thenReturn(itemFetchJob);
@@ -781,8 +764,7 @@ private slots:
 
         // WHEN
         QScopedPointer<Akonadi::TaskRepository> repository(new Akonadi::TaskRepository(storageMock.getInstance(),
-                                                                                       serializerMock.getInstance(),
-                                                                                       Akonadi::MessagingInterface::Ptr()));
+                                                                                       serializerMock.getInstance()));
         repository->dissociateAll(child)->exec();
 
         // THEN
@@ -791,46 +773,13 @@ private slots:
         if (!childJobFailed) {
             QVERIFY(serializerMock(&Akonadi::SerializerInterface::removeItemParent).when(childItem).exactly(1));
             QVERIFY(serializerMock(&Akonadi::SerializerInterface::clearItem).when(any<Akonadi::Item*>()).exactly(1));
-            QVERIFY(storageMock(&Akonadi::StorageInterface::updateItem).when(childItem, Q_NULLPTR).exactly(1));
+            QVERIFY(storageMock(&Akonadi::StorageInterface::updateItem).when(childItem, nullptr).exactly(1));
         }
 
         // Give a chance to job to delete themselves
         // in case of an error (since they use deleteLater() internally)
         QTest::qWait(10);
     }
-
-    void shouldSendDelegationMessage()
-    {
-        // GIVEN
-        auto oldDelegate = Domain::Task::Delegate(QStringLiteral("John Smith"), QStringLiteral("john@smith.com"));
-        auto newDelegate = Domain::Task::Delegate(QStringLiteral("John Doe"), QStringLiteral("john@doe.com"));
-
-        auto task = Domain::Task::Ptr::create();
-        task->setDelegate(oldDelegate);
-
-        QSignalSpy spy(task.data(), &Domain::Task::delegateChanged);
-
-        auto item = Akonadi::Item(42);
-
-        Utils::MockObject<Akonadi::SerializerInterface> serializerMock;
-        serializerMock(&Akonadi::SerializerInterface::createItemFromTask).when(task).thenReturn(item);
-
-        Utils::MockObject<Akonadi::MessagingInterface> messagingMock;
-        messagingMock(&Akonadi::MessagingInterface::sendDelegationMessage).when(item).thenReturn();
-
-        // WHEN
-        QScopedPointer<Akonadi::TaskRepository> repository(new Akonadi::TaskRepository(Akonadi::StorageInterface::Ptr(),
-                                                                                       serializerMock.getInstance(),
-                                                                                       messagingMock.getInstance()));
-        repository->delegate(task, newDelegate);
-
-        // THEN
-        QVERIFY(serializerMock(&Akonadi::SerializerInterface::createItemFromTask).when(task).exactly(1));
-        QVERIFY(messagingMock(&Akonadi::MessagingInterface::sendDelegationMessage).when(item).exactly(1));
-
-        QCOMPARE(task->delegate(), oldDelegate);
-        QVERIFY(spy.isEmpty());
-    }
 };
 
 ZANSHIN_TEST_MAIN(AkonadiTaskRepositoryTest)
