@@ -40,7 +40,7 @@ using namespace mockitopp::matcher;
 class FakeErrorHandler : public Presentation::ErrorHandler
 {
 public:
-    void doDisplayMessage(const QString &message)
+    void doDisplayMessage(const QString &message) override
     {
         m_message = message;
     }
@@ -150,15 +150,15 @@ private slots:
 
         // THEN
         QVERIFY(data->hasFormat(QStringLiteral("application/x-zanshin-object")));
-        QCOMPARE(data->property("objects").value<Domain::Artifact::List>(),
-                 Domain::Artifact::List() << childTask);
+        QCOMPARE(data->property("objects").value<Domain::Task::List>(),
+                 Domain::Task::List() << childTask);
 
         // WHEN
         auto childTask2 = Domain::Task::Ptr::create();
         taskRepositoryMock(&Domain::TaskRepository::associate).when(rootTask, childTask2).thenReturn(new FakeJob(this));
         data.reset(new QMimeData);
         data->setData(QStringLiteral("application/x-zanshin-object"), "object");
-        data->setProperty("objects", QVariant::fromValue(Domain::Artifact::List() << childTask2));
+        data->setProperty("objects", QVariant::fromValue(Domain::Task::List() << childTask2));
         model->dropMimeData(data.get(), Qt::MoveAction, -1, -1, rootTaskIndex);
 
         // THEN
@@ -172,7 +172,7 @@ private slots:
         taskRepositoryMock(&Domain::TaskRepository::associate).when(rootTask, childTask4).thenReturn(new FakeJob(this));
         data.reset(new QMimeData);
         data->setData(QStringLiteral("application/x-zanshin-object"), "object");
-        data->setProperty("objects", QVariant::fromValue(Domain::Artifact::List() << childTask3 << childTask4));
+        data->setProperty("objects", QVariant::fromValue(Domain::Task::List() << childTask3 << childTask4));
         model->dropMimeData(data.get(), Qt::MoveAction, -1, -1, rootTaskIndex);
 
         // THEN
@@ -206,7 +206,7 @@ private slots:
 
         // WHEN
         auto title = QStringLiteral("New task");
-        auto task = page.addItem(title).objectCast<Domain::Task>();
+        auto task = page.addItem(title);
 
         // THEN
         QVERIFY(taskRepositoryMock(&Domain::TaskRepository::createInProject).when(any<Domain::Task::Ptr>(),
@@ -254,7 +254,7 @@ private slots:
         // WHEN
         const auto title = QStringLiteral("New task");
         const auto parentIndex = page.centralListModel()->index(0, 0);
-        const auto createdTask = page.addItem(title, parentIndex).objectCast<Domain::Task>();
+        const auto createdTask = page.addItem(title, parentIndex);
 
         // THEN
         QVERIFY(taskRepositoryMock(&Domain::TaskRepository::createChild).when(any<Domain::Task::Ptr>(),
@@ -573,7 +573,7 @@ private slots:
         taskRepositoryMock(&Domain::TaskRepository::associate).when(rootTask, childTask4).thenReturn(new FakeJob(this));
         auto data = std::make_unique<QMimeData>();
         data->setData(QStringLiteral("application/x-zanshin-object"), "object");
-        data->setProperty("objects", QVariant::fromValue(Domain::Artifact::List() << childTask3 << childTask4));
+        data->setProperty("objects", QVariant::fromValue(Domain::Task::List() << childTask3 << childTask4));
         model->dropMimeData(data.get(), Qt::MoveAction, -1, -1, rootTaskIndex);
 
         // THEN
@@ -635,7 +635,7 @@ private slots:
 
         auto data = std::make_unique<QMimeData>();
         data->setData(QStringLiteral("application/x-zanshin-object"), "object");
-        data->setProperty("objects", QVariant::fromValue(Domain::Artifact::List() << childTask1 << childTask2)); // both will be DnD on the empty part
+        data->setProperty("objects", QVariant::fromValue(Domain::Task::List() << childTask1 << childTask2)); // both will be DnD on the empty part
         model->dropMimeData(data.get(), Qt::MoveAction, -1, -1, QModelIndex());
 
         // THEN
