@@ -33,11 +33,11 @@
 
 #include "utils/mem_fn.h"
 
-#include "domain/note.h"
 #include "domain/task.h"
 
-#include "presentation/artifactfilterproxymodel.h"
+#include "presentation/taskfilterproxymodel.h"
 #include "presentation/querytreemodelbase.h"
+#include "presentation/runningtaskmodelinterface.h"
 
 #include "widgets/applicationcomponents.h"
 #include "widgets/availablepagesview.h"
@@ -47,13 +47,14 @@
 #include "widgets/pageview.h"
 #include "widgets/pageviewerrorhandler.h"
 #include "widgets/quickselectdialog.h"
+#include "widgets/runningtaskwidget.h"
 
 
 class CustomModelStub : public QStandardItemModel
 {
     Q_OBJECT
 
-    QMimeData *mimeData(const QModelIndexList &indexes) const
+    QMimeData *mimeData(const QModelIndexList &indexes) const override
     {
         QStringList dataString;
         std::transform(indexes.begin(), indexes.end(),
@@ -69,7 +70,7 @@ class CustomModelStub : public QStandardItemModel
         return data;
     }
 
-    bool dropMimeData(const QMimeData *data, Qt::DropAction action, int row, int column, const QModelIndex &destination)
+    bool dropMimeData(const QMimeData *data, Qt::DropAction action, int row, int column, const QModelIndex &destination) override
     {
         Q_UNUSED(action);
 
@@ -99,8 +100,8 @@ class ApplicationModelStub : public QObject
 public:
     typedef QSharedPointer<ApplicationModelStub> Ptr;
 
-    explicit ApplicationModelStub(QObject *parent = Q_NULLPTR)
-        : QObject(parent), m_currentPage(Q_NULLPTR) {}
+    explicit ApplicationModelStub(QObject *parent = nullptr)
+        : QObject(parent), m_currentPage(nullptr) {}
 
     QObject *currentPage()
     {
@@ -128,7 +129,7 @@ class AvailablePagesModelStub : public QObject
     Q_OBJECT
     Q_PROPERTY(QAbstractItemModel* pageListModel READ pageListModel)
 public:
-    explicit AvailablePagesModelStub(QObject *parent = Q_NULLPTR)
+    explicit AvailablePagesModelStub(QObject *parent = nullptr)
         : QObject(parent)
     {
         QStandardItem *inbox = new QStandardItem;
@@ -171,26 +172,25 @@ public:
         return &itemModel;
     }
 
-    template<typename T>
-    void addItem(const QString &title)
+    void addTask(const QString &title)
     {
-        auto artifact = T::Ptr::create();
-        artifact->setTitle(title);
-        addItem(artifact);
+        auto task = Domain::Task::Ptr::create();
+        task->setTitle(title);
+        addTask(task);
     }
 
-    void addItem(const Domain::Artifact::Ptr &artifact)
+    void addTask(const Domain::Task::Ptr &task)
     {
         QStandardItem *item = new QStandardItem;
-        item->setData(QVariant::fromValue(artifact), Presentation::QueryTreeModelBase::ObjectRole);
-        item->setData(artifact->title(), Qt::DisplayRole);
+        item->setData(QVariant::fromValue(task), Presentation::QueryTreeModelBase::ObjectRole);
+        item->setData(task->title(), Qt::DisplayRole);
         itemModel.appendRow(item);
     }
 
-    Domain::Artifact::Ptr itemAtRow(int row) const
+    Domain::Task::Ptr itemAtRow(int row) const
     {
         return itemModel.index(row, 0).data(Presentation::QueryTreeModelBase::ObjectRole)
-                                      .value<Domain::Artifact::Ptr>();
+                                      .value<Domain::Task::Ptr>();
     }
 
     QModelIndexList selectedIndexes() const
@@ -207,7 +207,7 @@ class EditorModelStub : public QObject
 {
     Q_OBJECT
 public:
-    explicit EditorModelStub(QObject *parent = Q_NULLPTR)
+    explicit EditorModelStub(QObject *parent = nullptr)
         : QObject(parent)
     {
     }
@@ -225,11 +225,9 @@ public:
         else if (name == "done")
             emit doneChanged(value.toBool());
         else if (name == "startDate")
-            emit startDateChanged(value.toDateTime());
+            emit startDateChanged(value.toDate());
         else if (name == "dueDate")
-            emit dueDateChanged(value.toDateTime());
-        else if (name == "hasTaskProperties")
-            emit hasTaskPropertiesChanged(value.toBool());
+            emit dueDateChanged(value.toDate());
         else
             qFatal("Unsupported property %s", name.constData());
     }
@@ -238,16 +236,31 @@ public slots:
     void setTitle(const QString &title) { setPropertyAndSignal("title", title); }
     void setText(const QString &text) { setPropertyAndSignal("text", text); }
     void setDone(bool done) { setPropertyAndSignal("done", done); }
-    void setStartDate(const QDateTime &start) { setPropertyAndSignal("startDate", start); }
-    void setDueDate(const QDateTime &due) { setPropertyAndSignal("dueDate", due); }
+    void setStartDate(const QDate &start) { setPropertyAndSignal("startDate", start); }
+    void setDueDate(const QDate &due) { setPropertyAndSignal("dueDate", due); }
 
 signals:
-    void hasTaskPropertiesChanged(bool hasTaskProperties);
     void textChanged(const QString &text);
     void titleChanged(const QString &title);
     void doneChanged(bool done);
-    void startDateChanged(const QDateTime &date);
-    void dueDateChanged(const QDateTime &due);
+    void startDateChanged(const QDate &date);
+    void dueDateChanged(const QDate &due);
+};
+
+class RunningTaskModelStub : public Presentation::RunningTaskModelInterface
+{
+    Q_OBJECT
+public:
+    explicit RunningTaskModelStub(QObject *parent = nullptr)
+        : Presentation::RunningTaskModelInterface(parent)
+    {
+    }
+
+    Domain::Task::Ptr runningTask() const override { return {}; }
+    void setRunningTask(const Domain::Task::Ptr &) override {}
+    void taskDeleted(const Domain::Task::Ptr &) override {}
+    void stopTask() override {}
+    void doneTask() override {}
 };
 
 class QuickSelectDialogStub : public Widgets::QuickSelectDialogInterface
@@ -256,24 +269,24 @@ public:
     typedef QSharedPointer<QuickSelectDialogStub> Ptr;
 
     explicit QuickSelectDialogStub()
-        : parent(Q_NULLPTR),
+        : parent(nullptr),
           execCount(0),
-          itemModel(Q_NULLPTR)
+          itemModel(nullptr)
     {
     }
 
-    int exec() Q_DECL_OVERRIDE
+    int exec() override
     {
         execCount++;
         return QDialog::Accepted;
     }
 
-    void setModel(QAbstractItemModel *model) Q_DECL_OVERRIDE
+    void setModel(QAbstractItemModel *model) override
     {
         itemModel = model;
     }
 
-    QPersistentModelIndex selectedIndex() const Q_DECL_OVERRIDE
+    QPersistentModelIndex selectedIndex() const override
     {
         return index;
     }
@@ -288,7 +301,7 @@ class ApplicationComponentsTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit ApplicationComponentsTest(QObject *parent = Q_NULLPTR)
+    explicit ApplicationComponentsTest(QObject *parent = nullptr)
         : QObject(parent)
     {
         qputenv("ZANSHIN_UNIT_TEST_RUN", "1");
@@ -428,6 +441,39 @@ private slots:
         QCOMPARE(components.pageView()->model(), &currentPage);
     }
 
+    void shouldApplyRunningTaskModelToPageView()
+    {
+        // GIVEN
+        Widgets::ApplicationComponents components;
+        auto model = QObjectPtr::create();
+        auto runningTaskModel = new RunningTaskModelStub(model.data());
+        model->setProperty("runningTaskModel", QVariant::fromValue<Presentation::RunningTaskModelInterface*>(runningTaskModel));
+
+        // WHEN
+        components.setModel(model);
+
+        // THEN
+        QCOMPARE(components.pageView()->runningTaskModel(), runningTaskModel);
+    }
+
+    void shouldApplyRunningTaskModelAlsoToCreatedPageView()
+    {
+        // GIVEN
+        Widgets::ApplicationComponents components;
+        // Force creation
+        components.pageView();
+
+        auto model = QObjectPtr::create();
+        auto runningTaskModel = new RunningTaskModelStub(model.data());
+        model->setProperty("runningTaskModel", QVariant::fromValue<Presentation::RunningTaskModelInterface*>(runningTaskModel));
+
+        // WHEN
+        components.setModel(model);
+
+        // THEN
+        QCOMPARE(components.pageView()->runningTaskModel(), runningTaskModel);
+    }
+
     void shouldApplyEditorModelToEditorView()
     {
         // GIVEN
@@ -443,7 +489,7 @@ private slots:
         QCOMPARE(components.editorView()->model(), editorModel);
     }
 
-    void shouldApplyEditorModelAltoToCreatedPageView()
+    void shouldApplyEditorModelAlsoToCreatedPageView()
     {
         // GIVEN
         Widgets::ApplicationComponents components;
@@ -461,6 +507,40 @@ private slots:
         QCOMPARE(components.editorView()->model(), editorModel);
     }
 
+    void shouldApplyRunningTaskModelToRunningTaskView()
+    {
+        // GIVEN
+        Widgets::ApplicationComponents components;
+        auto model = QObjectPtr::create();
+        auto runningTaskModel = new RunningTaskModelStub(model.data());
+        model->setProperty("runningTaskModel", QVariant::fromValue<Presentation::RunningTaskModelInterface*>(runningTaskModel));
+
+        // WHEN
+        components.setModel(model);
+
+        // THEN
+        QCOMPARE(components.runningTaskView()->model(), runningTaskModel);
+    }
+
+    void shouldApplyRunningTaskModelAlsoToCreatedRunningTaskView()
+    {
+        // GIVEN
+        Widgets::ApplicationComponents components;
+        // Force creation
+        components.runningTaskView();
+
+        auto model = QObjectPtr::create();
+        auto runningTaskModel = new RunningTaskModelStub(model.data());
+        model->setProperty("runningTaskModel", QVariant::fromValue<Presentation::RunningTaskModelInterface*>(runningTaskModel));
+
+        // WHEN
+        components.setModel(model);
+
+        // THEN
+        QCOMPARE(components.runningTaskView()->model(), runningTaskModel);
+    }
+
+
     void shouldPropageNullModelsToViews()
     {
         // GIVEN
@@ -475,6 +555,8 @@ private slots:
         model->setProperty("currentPage", QVariant::fromValue(currentPage));
         auto editorModel = new EditorModelStub(model.data());
         model->setProperty("editor", QVariant::fromValue<QObject*>(editorModel));
+        auto runningTaskModel = new RunningTaskModelStub(model.data());
+        model->setProperty("runningTaskModel", QVariant::fromValue<Presentation::RunningTaskModelInterface*>(runningTaskModel));
 
         components.setModel(model);
 
@@ -484,12 +566,14 @@ private slots:
         components.availablePagesView();
         components.pageView();
         components.editorView();
+        components.runningTaskView();
 
         // THEN
         QVERIFY(!components.availableSourcesView()->model());
         QVERIFY(!components.availablePagesView()->model());
         QVERIFY(!components.pageView()->model());
         QVERIFY(!components.editorView()->model());
+        QVERIFY(!components.runningTaskView()->model());
     }
 
     void shouldPropageNullModelsToCreatedViews()
@@ -500,6 +584,7 @@ private slots:
         components.availablePagesView();
         components.pageView();
         components.editorView();
+        components.runningTaskView();
 
         auto model = QObjectPtr::create();
         auto availableSources = new QObject(model.data());
@@ -510,6 +595,8 @@ private slots:
         model->setProperty("currentPage", QVariant::fromValue(currentPage));
         auto editorModel = new EditorModelStub(model.data());
         model->setProperty("editor", QVariant::fromValue<QObject*>(editorModel));
+        auto runningTaskModel = new RunningTaskModelStub(model.data());
+        model->setProperty("runningTaskModel", QVariant::fromValue<Presentation::RunningTaskModelInterface*>(runningTaskModel));
 
         components.setModel(model);
 
@@ -521,6 +608,7 @@ private slots:
         QVERIFY(!components.availablePagesView()->model());
         QVERIFY(!components.pageView()->model());
         QVERIFY(!components.editorView()->model());
+        QVERIFY(!components.runningTaskView()->model());
     }
 
     void shouldApplyAvailablePagesSelectionToApplicationModel()
@@ -530,11 +618,11 @@ private slots:
 
         AvailablePagesModelStub availablePagesModel;
         model->setProperty("availablePages", QVariant::fromValue<QObject*>(&availablePagesModel));
-        model->setProperty("currentPage", QVariant::fromValue<QObject*>(Q_NULLPTR));
+        model->setProperty("currentPage", QVariant::fromValue<QObject*>(nullptr));
 
         QObject editorModel;
-        editorModel.setProperty("artifact",
-                                QVariant::fromValue<Domain::Artifact::Ptr>(Domain::Task::Ptr::create()));
+        editorModel.setProperty("task",
+                                QVariant::fromValue(Domain::Task::Ptr::create()));
         model->setProperty("editor", QVariant::fromValue<QObject*>(&editorModel));
 
         Widgets::ApplicationComponents components;
@@ -559,7 +647,7 @@ private slots:
                  availablePagesModel.createdPages.first());
         QCOMPARE(pageView->model(),
                  availablePagesModel.createdPages.first());
-        QVERIFY(editorModel.property("artifact").value<Domain::Artifact::Ptr>().isNull());
+        QVERIFY(editorModel.property("task").value<Domain::Task::Ptr>().isNull());
     }
 
     void shouldApplyPageViewSelectionToEditorModel()
@@ -568,10 +656,10 @@ private slots:
         auto model = QObjectPtr::create();
 
         PageModelStub pageModel;
-        pageModel.addItem<Domain::Task>(QStringLiteral("0. First task"));
-        pageModel.addItem<Domain::Note>(QStringLiteral("1. A note"));
-        pageModel.addItem<Domain::Task>(QStringLiteral("2. Second task"));
-        pageModel.addItem<Domain::Note>(QStringLiteral("3. Another note"));
+        pageModel.addTask(QStringLiteral("0. First task"));
+        pageModel.addTask(QStringLiteral("1. Second task"));
+        pageModel.addTask(QStringLiteral("2. Third task"));
+        pageModel.addTask(QStringLiteral("3. Yet another task"));
         model->setProperty("currentPage", QVariant::fromValue<QObject*>(&pageModel));
 
         EditorModelStub editorModel;
@@ -588,7 +676,7 @@ private slots:
         centralView->selectionModel()->setCurrentIndex(index, QItemSelectionModel::ClearAndSelect);
 
         // THEN
-        QCOMPARE(editorModel.property("artifact").value<Domain::Artifact::Ptr>(),
+        QCOMPARE(editorModel.property("task").value<Domain::Task::Ptr>(),
                  pageModel.itemAtRow(index.row()));
     }
 
@@ -604,18 +692,21 @@ private slots:
 
         // availablePages view
         auto available = components.availablePagesView();
-        foreach (const auto &key,  available->globalActions().keys())
-            QCOMPARE(actions.value(key), available->globalActions().value(key));
+        auto availableGlobalActions = available->globalActions();
+        for (auto it = availableGlobalActions.cbegin(); it != availableGlobalActions.cend(); ++it)
+            QCOMPARE(actions.value(it.key()), it.value());
 
         // availableSources view
         auto availableSources = components.availableSourcesView();
-        foreach (const auto &key, availableSources->globalActions().keys())
-            QCOMPARE(actions.value(key), availableSources->globalActions().value(key));
+        auto availableSourcesGlobalActions = availableSources->globalActions();
+        for (auto it = availableSourcesGlobalActions.cbegin(); it != availableSourcesGlobalActions.cend(); ++it)
+            QCOMPARE(actions.value(it.key()), it.value());
 
         // page view
         auto page = components.pageView();
-        foreach (const auto &key, page->globalActions().keys())
-            QCOMPARE(actions.value(key), page->globalActions().value(key));
+        auto pageGlobalActions = page->globalActions();
+        for (auto it = pageGlobalActions.cbegin(); it != pageGlobalActions.cend(); ++it)
+            QCOMPARE(actions.value(it.key()), it.value());
 
         // application component own action
         auto moveAction = components.findChild<QAction*>(QStringLiteral("moveItemAction"));
@@ -628,10 +719,10 @@ private slots:
         auto model = QObjectPtr::create();
 
         PageModelStub pageModel;
-        pageModel.addItem<Domain::Task>(QStringLiteral("0. First task"));
-        pageModel.addItem<Domain::Note>(QStringLiteral("1. A note"));
-        pageModel.addItem<Domain::Task>(QStringLiteral("2. Second task"));
-        pageModel.addItem<Domain::Note>(QStringLiteral("3. Another note"));
+        pageModel.addTask(QStringLiteral("0. First task"));
+        pageModel.addTask(QStringLiteral("1. Second task"));
+        pageModel.addTask(QStringLiteral("2. Third task"));
+        pageModel.addTask(QStringLiteral("3. Yet another task"));
         model->setProperty("currentPage", QVariant::fromValue<QObject*>(&pageModel));
 
         AvailablePagesModelStub availablePagesModelStub;
