@@ -34,55 +34,60 @@
 
 #include "domain/project.h"
 #include "domain/context.h"
-#include "domain/tag.h"
 
 #include "presentation/metatypes.h"
 #include "presentation/querytreemodelbase.h"
 
 #include "widgets/availablepagesview.h"
-#include "widgets/newprojectdialog.h"
+#include "widgets/nameanddatasourcedialog.h"
 #include "widgets/quickselectdialog.h"
 
 #include "messageboxstub.h"
 
-class NewProjectDialogStub : public Widgets::NewProjectDialogInterface
+class NameAndDataSourceDialogStub : public Widgets::NameAndDataSourceDialogInterface
 {
 public:
-    typedef QSharedPointer<NewProjectDialogStub> Ptr;
+    typedef QSharedPointer<NameAndDataSourceDialogStub> Ptr;
 
-    explicit NewProjectDialogStub()
-        : parent(Q_NULLPTR),
+    explicit NameAndDataSourceDialogStub()
+        : parent(nullptr),
           execCount(0),
-          sourceModel(Q_NULLPTR),
+          sourceModel(nullptr),
           source(Domain::DataSource::Ptr::create())
     {
     }
 
-    int exec() Q_DECL_OVERRIDE
+    int exec() override
     {
         execCount++;
         return QDialog::Accepted;
     }
 
-    void setDataSourcesModel(QAbstractItemModel *model) Q_DECL_OVERRIDE
+    void setDataSourcesModel(QAbstractItemModel *model) override
     {
         sourceModel = model;
     }
 
-    QString name() const Q_DECL_OVERRIDE
+    QString name() const override
     {
         return QStringLiteral("name");
     }
 
-    Domain::DataSource::Ptr dataSource() const Q_DECL_OVERRIDE
+    Domain::DataSource::Ptr dataSource() const override
     {
         return source;
     }
 
+    void setWindowTitle(const QString &title) override
+    {
+        windowTitle = title;
+    }
+
     QWidget *parent;
     int execCount;
     QAbstractItemModel *sourceModel;
     Domain::DataSource::Ptr source;
+    QString windowTitle;
 };
 
 class QuickSelectDialogStub : public Widgets::QuickSelectDialogInterface
@@ -91,24 +96,24 @@ public:
     typedef QSharedPointer<QuickSelectDialogStub> Ptr;
 
     explicit QuickSelectDialogStub()
-        : parent(Q_NULLPTR),
+        : parent(nullptr),
           execCount(0),
-          itemModel(Q_NULLPTR)
+          itemModel(nullptr)
     {
     }
 
-    int exec() Q_DECL_OVERRIDE
+    int exec() override
     {
         execCount++;
         return QDialog::Accepted;
     }
 
-    void setModel(QAbstractItemModel *model) Q_DECL_OVERRIDE
+    void setModel(QAbstractItemModel *model) override
     {
         itemModel = model;
     }
 
-    QPersistentModelIndex selectedIndex() const Q_DECL_OVERRIDE
+    QPersistentModelIndex selectedIndex() const override
     {
         return index;
     }
@@ -123,7 +128,7 @@ class AvailablePagesModelStub : public QObject
 {
     Q_OBJECT
 public:
-    explicit AvailablePagesModelStub(QObject *parent = Q_NULLPTR)
+    explicit AvailablePagesModelStub(QObject *parent = nullptr)
         : QObject(parent)
     {
     }
@@ -134,14 +139,10 @@ public slots:
         sources << source;
     }
 
-    void addContext(const QString &name)
+    void addContext(const QString &name, const Domain::DataSource::Ptr &source)
     {
         contextNames << name;
-    }
-
-    void addTag(const QString &name)
-    {
-        tagNames << name;
+        sources << source;
     }
 
     void removeItem(const QModelIndex &index)
@@ -150,12 +151,11 @@ public slots:
     }
 
 public Q_SLOTS:
-    QObject *createPageForIndex(const QModelIndex &) { return Q_NULLPTR; }
+    QObject *createPageForIndex(const QModelIndex &) { return nullptr; }
 
 public:
     QStringList projectNames;
     QStringList contextNames;
-    QStringList tagNames;
     QList<Domain::DataSource::Ptr> sources;
     QString projectRemoved;
 };
@@ -186,8 +186,6 @@ private slots:
         QVERIFY(addProjectAction);
         auto addContextAction = available.findChild<QAction*>(QStringLiteral("addContextAction"));
         QVERIFY(addContextAction);
-        auto addTagAction = available.findChild<QAction*>(QStringLiteral("addTagAction"));
-        QVERIFY(addTagAction);
         auto removeAction = available.findChild<QAction*>(QStringLiteral("removeAction"));
         QVERIFY(removeAction);
         auto goPreviousAction = available.findChild<QAction*>(QStringLiteral("goPreviousAction"));
@@ -198,7 +196,7 @@ private slots:
         QVERIFY(goToAction);
 
         auto projectDialogFactory = available.projectDialogFactory();
-        QVERIFY(projectDialogFactory(&available).dynamicCast<Widgets::NewProjectDialog>());
+        QVERIFY(projectDialogFactory(&available).dynamicCast<Widgets::NameAndDataSourceDialog>());
 
         auto quickSelectDialogFactory = available.quickSelectDialogFactory();
         QVERIFY(quickSelectDialogFactory(&available).dynamicCast<Widgets::QuickSelectDialog>());
@@ -206,58 +204,12 @@ private slots:
         auto actions = available.globalActions();
         QCOMPARE(actions.value(QStringLiteral("pages_project_add")), addProjectAction);
         QCOMPARE(actions.value(QStringLiteral("pages_context_add")), addContextAction);
-        QCOMPARE(actions.value(QStringLiteral("pages_tag_add")), addTagAction);
         QCOMPARE(actions.value(QStringLiteral("pages_remove")), removeAction);
         QCOMPARE(actions.value(QStringLiteral("pages_go_previous")), goPreviousAction);
         QCOMPARE(actions.value(QStringLiteral("pages_go_next")), goNextAction);
         QCOMPARE(actions.value(QStringLiteral("pages_go_to")), goToAction);
     }
 
-    void shouldShowOnlyAddActionsNeededByTheModel_data()
-    {
-        QTest::addColumn<bool>("hasProjects");
-        QTest::addColumn<bool>("hasContexts");
-        QTest::addColumn<bool>("hasTags");
-
-        QTest::newRow("!projects !contexts !tags") << false << false << false;
-        QTest::newRow("!projects !contexts tags") << false << false << true;
-        QTest::newRow("!projects contexts !tags") << false << true << false;
-        QTest::newRow("!projects contexts tags") << false << true << true;
-        QTest::newRow("projects !contexts !tags") << true << false << false;
-        QTest::newRow("projects !contexts tags") << true << false << true;
-        QTest::newRow("projects contexts !tags") << true << true << false;
-        QTest::newRow("projects contexts tags") << true << true << true;
-    }
-
-    void shouldShowOnlyAddActionsNeededByTheModel()
-    {
-        // GIVEN
-        QFETCH(bool, hasProjects);
-        QFETCH(bool, hasContexts);
-        QFETCH(bool, hasTags);
-
-        AvailablePagesModelStub stubPagesModel;
-        stubPagesModel.setProperty("hasProjectPages", hasProjects);
-        stubPagesModel.setProperty("hasContextPages", hasContexts);
-        stubPagesModel.setProperty("hasTagPages", hasTags);
-
-        Widgets::AvailablePagesView available;
-        auto addProjectAction = available.findChild<QAction*>(QStringLiteral("addProjectAction"));
-        QVERIFY(addProjectAction);
-        auto addContextAction = available.findChild<QAction*>(QStringLiteral("addContextAction"));
-        QVERIFY(addContextAction);
-        auto addTagAction = available.findChild<QAction*>(QStringLiteral("addTagAction"));
-        QVERIFY(addTagAction);
-
-        // WHEN
-        available.setModel(&stubPagesModel);
-
-        // THEN
-        QCOMPARE(addProjectAction->isVisible(), hasProjects);
-        QCOMPARE(addContextAction->isVisible(), hasContexts);
-        QCOMPARE(addTagAction->isVisible(), hasTags);
-    }
-
     void shouldDisplayListFromPageModel()
     {
         // GIVEN
@@ -297,7 +249,7 @@ private slots:
         QCOMPARE(pagesView->model(), &model);
 
         // WHEN
-        available.setModel(Q_NULLPTR);
+        available.setModel(nullptr);
         QTest::qWait(10);
 
         // THEN
@@ -310,7 +262,7 @@ private slots:
         // GIVEN
         AvailablePagesModelStub model;
         QStringListModel sourceModel;
-        auto dialogStub = NewProjectDialogStub::Ptr::create();
+        auto dialogStub = NameAndDataSourceDialogStub::Ptr::create();
 
         auto source = Domain::DataSource::Ptr::create();
 
@@ -344,18 +296,18 @@ private slots:
         // GIVEN
         AvailablePagesModelStub model;
         QStringListModel sourceModel;
-        auto dialogStub = NewProjectDialogStub::Ptr::create();
+        auto dialogStub = NameAndDataSourceDialogStub::Ptr::create();
 
         auto source = Domain::DataSource::Ptr::create();
 
-        auto msgBoxStub = MessageBoxStub::Ptr::create();
-        msgBoxStub->setTextInput(QStringLiteral("Foo"));
-
         Widgets::AvailablePagesView available;
         available.setModel(&model);
         available.setProjectSourcesModel(&sourceModel);
         available.setDefaultProjectSource(source);
-        available.setMessageBoxInterface(msgBoxStub);
+        available.setProjectDialogFactory([dialogStub] (QWidget *parent) {
+            dialogStub->parent = parent;
+            return dialogStub;
+        });
 
         auto addContextAction = available.findChild<QAction*>(QStringLiteral("addContextAction"));
 
@@ -363,38 +315,15 @@ private slots:
         addContextAction->trigger();
 
         // THEN
-        QVERIFY(msgBoxStub->called());
+        QCOMPARE(dialogStub->execCount, 1);
+        QCOMPARE(dialogStub->parent, &available);
+        QCOMPARE(dialogStub->sourceModel, &sourceModel);
+        QCOMPARE(dialogStub->windowTitle, QStringLiteral("Add a context"));
         QCOMPARE(model.contextNames.size(), 1);
-        QCOMPARE(model.contextNames.first(), QStringLiteral("Foo"));
-    }
-
-    void shouldAddNewTags()
-    {
-        // GIVEN
-        AvailablePagesModelStub model;
-        QStringListModel sourceModel;
-        auto dialogStub = NewProjectDialogStub::Ptr::create();
-
-        auto source = Domain::DataSource::Ptr::create();
-
-        auto msgBoxStub = MessageBoxStub::Ptr::create();
-        msgBoxStub->setTextInput(QStringLiteral("Foo"));
-
-        Widgets::AvailablePagesView available;
-        available.setModel(&model);
-        available.setProjectSourcesModel(&sourceModel);
-        available.setDefaultProjectSource(source);
-        available.setMessageBoxInterface(msgBoxStub);
-
-        auto addTagAction = available.findChild<QAction*>(QStringLiteral("addTagAction"));
-
-        // WHEN
-        addTagAction->trigger();
-
-        // THEN
-        QVERIFY(msgBoxStub->called());
-        QCOMPARE(model.tagNames.size(), 1);
-        QCOMPARE(model.tagNames.first(), QStringLiteral("Foo"));
+        QCOMPARE(model.contextNames.first(), QStringLiteral("name"));
+        QCOMPARE(model.sources.size(), 1);
+        QCOMPARE(model.sources.first(), dialogStub->dataSource());
+        QCOMPARE(available.defaultProjectSource(), dialogStub->dataSource());
     }
 
     void shouldRemoveAPage_data()
@@ -410,10 +339,6 @@ private slots:
         context1->setName(QStringLiteral("Context 1"));
         QTest::newRow("context") << QObjectPtr(context1) << true;
 
-        auto tag1 = Domain::Tag::Ptr::create();
-        tag1->setName(QStringLiteral("Tag 1"));
-        QTest::newRow("tag") << QObjectPtr(tag1) << true;
-
         QTest::newRow("non removable") << QObjectPtr::create() << false;
     }
 
