@@ -32,12 +32,10 @@
 
 #include <KLocalizedString>
 
-#include "domain/note.h"
 #include "domain/task.h"
 
 #include "widgets/editorview.h"
 
-#include "addressline/addresseelineedit.h"
 #include "kdateedit.h"
 
 class EditorModelStub : public QObject
@@ -58,8 +56,8 @@ public:
             return;
 
         setProperty(name, value);
-        if (name == "artifact")
-            emit artifactChanged(value.value<Domain::Artifact::Ptr>());
+        if (name == "task")
+            emit taskChanged(value.value<Domain::Task::Ptr>());
         else if (name == "text")
             emit textChanged(value.toString());
         else if (name == "title")
@@ -67,35 +65,24 @@ public:
         else if (name == "done")
             emit doneChanged(value.toBool());
         else if (name == "startDate")
-            emit startDateChanged(value.toDateTime());
+            emit startDateChanged(value.toDate());
         else if (name == "dueDate")
-            emit dueDateChanged(value.toDateTime());
+            emit dueDateChanged(value.toDate());
         else if (name == "recurrence")
             emit recurrenceChanged(value.value<Domain::Task::Recurrence>());
-        else if (name == "delegateText")
-            emit delegateTextChanged(value.toString());
-        else if (name == "hasTaskProperties")
-            emit hasTaskPropertiesChanged(value.toBool());
         else
             qFatal("Unsupported property %s", name.constData());
     }
 
 public slots:
-    void setArtifact(const Domain::Artifact::Ptr &artifact) { setPropertyAndSignal("artifact", QVariant::fromValue(artifact)); }
+    void setTask(const Domain::Task::Ptr &task) { setPropertyAndSignal("task", QVariant::fromValue(task)); }
     void setTitle(const QString &title) { setPropertyAndSignal("title", title); }
     void setText(const QString &text) { setPropertyAndSignal("text", text); }
     void setDone(bool done) { setPropertyAndSignal("done", done); }
-    void setStartDate(const QDateTime &start) { setPropertyAndSignal("startDate", start); }
-    void setDueDate(const QDateTime &due) { setPropertyAndSignal("dueDate", due); }
+    void setStartDate(const QDate &start) { setPropertyAndSignal("startDate", start); }
+    void setDueDate(const QDate &due) { setPropertyAndSignal("dueDate", due); }
     void setRecurrence(Domain::Task::Recurrence recurrence) { setPropertyAndSignal("recurrence", QVariant::fromValue(recurrence)); }
-    void setDelegateText(const QString &text) { setPropertyAndSignal("delegateText", text); }
-    void makeTaskAvailable() { setArtifact(Domain::Artifact::Ptr(new Domain::Task)); }
-
-    void delegate(const QString &name, const QString &email)
-    {
-        delegateNames << name;
-        delegateEmails << email;
-    }
+    void makeTaskAvailable() { setTask(Domain::Task::Ptr(new Domain::Task)); }
 
     void addAttachment(const QString &fileName)
     {
@@ -110,19 +97,15 @@ public slots:
     }
 
 signals:
-    void artifactChanged(const Domain::Artifact::Ptr &artifact);
-    void hasTaskPropertiesChanged(bool hasTaskProperties);
+    void taskChanged(const Domain::Task::Ptr &task);
     void textChanged(const QString &text);
     void titleChanged(const QString &title);
     void doneChanged(bool done);
-    void startDateChanged(const QDateTime &date);
-    void dueDateChanged(const QDateTime &due);
+    void startDateChanged(const QDate &date);
+    void dueDateChanged(const QDate &due);
     void recurrenceChanged(Domain::Task::Recurrence recurrence);
-    void delegateTextChanged(const QString &delegateText);
 
 public:
-    QStringList delegateNames;
-    QStringList delegateEmails;
     QStandardItemModel attachmentModel;
 };
 
@@ -130,7 +113,7 @@ class EditorViewTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit EditorViewTest(QObject *parent = Q_NULLPTR)
+    explicit EditorViewTest(QObject *parent = nullptr)
         : QObject(parent)
     {
         qputenv("ZANSHIN_UNIT_TEST_RUN", "1");
@@ -149,39 +132,31 @@ private slots:
 
         auto startDateEdit = editor.findChild<KPIM::KDateEdit*>(QStringLiteral("startDateEdit"));
         QVERIFY(startDateEdit);
-        QVERIFY(!startDateEdit->isVisibleTo(&editor));
+        QVERIFY(startDateEdit->isVisibleTo(&editor));
 
         auto dueDateEdit = editor.findChild<KPIM::KDateEdit*>(QStringLiteral("dueDateEdit"));
         QVERIFY(dueDateEdit);
-        QVERIFY(!dueDateEdit->isVisibleTo(&editor));
+        QVERIFY(dueDateEdit->isVisibleTo(&editor));
 
         auto recurrenceCombo = editor.findChild<QComboBox*>(QStringLiteral("recurrenceCombo"));
         QVERIFY(recurrenceCombo);
-        QVERIFY(!recurrenceCombo->isVisibleTo(&editor));
+        QVERIFY(recurrenceCombo->isVisibleTo(&editor));
 
         auto doneButton = editor.findChild<QAbstractButton*>(QStringLiteral("doneButton"));
         QVERIFY(doneButton);
-        QVERIFY(!doneButton->isVisibleTo(&editor));
+        QVERIFY(doneButton->isVisibleTo(&editor));
 
         auto attachmentList = editor.findChild<QListView*>(QStringLiteral("attachmentList"));
         QVERIFY(attachmentList);
-        QVERIFY(!attachmentList->isVisibleTo(&editor));
+        QVERIFY(attachmentList->isVisibleTo(&editor));
 
         auto addAttachmentButton = editor.findChild<QToolButton*>(QStringLiteral("addAttachmentButton"));
         QVERIFY(addAttachmentButton);
-        QVERIFY(!addAttachmentButton->isVisibleTo(&editor));
+        QVERIFY(addAttachmentButton->isVisibleTo(&editor));
 
         auto removeAttachmentButton = editor.findChild<QToolButton*>(QStringLiteral("removeAttachmentButton"));
         QVERIFY(removeAttachmentButton);
-        QVERIFY(!removeAttachmentButton->isVisibleTo(&editor));
-
-        auto delegateLabel = editor.findChild<QLabel*>(QStringLiteral("delegateLabel"));
-        QVERIFY(delegateLabel);
-        QVERIFY(!delegateLabel->isVisibleTo(&editor));
-
-        auto delegateEdit = editor.findChild<KLineEdit*>(QStringLiteral("delegateEdit"));
-        QVERIFY(delegateEdit);
-        QVERIFY(!delegateEdit->isVisibleTo(&editor));
+        QVERIFY(removeAttachmentButton->isVisibleTo(&editor));
     }
 
     void shouldNotCrashForNullModel()
@@ -191,7 +166,6 @@ private slots:
         EditorModelStub model;
         model.setTitle(QStringLiteral("Foo"));
         model.setText(QStringLiteral("Bar"));
-        model.setPropertyAndSignal("hasTaskProperties", true);
         editor.setModel(&model);
 
         auto textEdit = editor.findChild<QPlainTextEdit*>(QStringLiteral("textEdit"));
@@ -219,14 +193,8 @@ private slots:
         auto removeAttachmentButton = editor.findChild<QToolButton*>(QStringLiteral("removeAttachmentButton"));
         QVERIFY(removeAttachmentButton);
 
-        auto delegateLabel = editor.findChild<QLabel*>(QStringLiteral("delegateLabel"));
-        QVERIFY(delegateLabel);
-
-        auto delegateEdit = editor.findChild<KLineEdit*>(QStringLiteral("delegateEdit"));
-        QVERIFY(delegateEdit);
-
         // WHEN
-        editor.setModel(Q_NULLPTR);
+        editor.setModel(nullptr);
 
         // THEN
         QVERIFY(!editor.isEnabled());
@@ -239,80 +207,9 @@ private slots:
         QVERIFY(attachmentList->model() == nullptr);
         QVERIFY(!addAttachmentButton->isVisibleTo(&editor));
         QVERIFY(!removeAttachmentButton->isVisibleTo(&editor));
-        QVERIFY(!delegateLabel->isVisibleTo(&editor));
-        QVERIFY(!delegateEdit->isVisibleTo(&editor));
     }
 
-    void shouldShowTaskPropertiesEditorsOnlyForTasks()
-    {
-        // GIVEN
-        Widgets::EditorView editor;
-        EditorModelStub model;
-        model.setPropertyAndSignal("hasTaskProperties", true);
-
-        auto startDateEdit = editor.findChild<KPIM::KDateEdit*>(QStringLiteral("startDateEdit"));
-        QVERIFY(!startDateEdit->isVisibleTo(&editor));
-
-        auto dueDateEdit = editor.findChild<KPIM::KDateEdit*>(QStringLiteral("dueDateEdit"));
-        QVERIFY(!dueDateEdit->isVisibleTo(&editor));
-
-        auto recurrenceCombo = editor.findChild<QComboBox*>(QStringLiteral("recurrenceCombo"));
-        QVERIFY(recurrenceCombo);
-
-        auto doneButton = editor.findChild<QAbstractButton*>(QStringLiteral("doneButton"));
-        QVERIFY(!doneButton->isVisibleTo(&editor));
-
-        auto attachmentList = editor.findChild<QListView*>(QStringLiteral("attachmentList"));
-        QVERIFY(attachmentList);
-
-        auto addAttachmentButton = editor.findChild<QToolButton*>(QStringLiteral("addAttachmentButton"));
-        QVERIFY(addAttachmentButton);
-
-        auto removeAttachmentButton = editor.findChild<QToolButton*>(QStringLiteral("removeAttachmentButton"));
-        QVERIFY(removeAttachmentButton);
-
-        auto delegateLabel = editor.findChild<QLabel*>(QStringLiteral("delegateLabel"));
-        QVERIFY(!delegateLabel->isVisibleTo(&editor));
-
-        auto delegateEdit = editor.findChild<KLineEdit*>(QStringLiteral("delegateEdit"));
-        QVERIFY(!delegateEdit->isVisibleTo(&editor));
-
-        // WHEN
-        editor.setModel(&model);
-
-        // THEN
-        QVERIFY(startDateEdit->isVisibleTo(&editor));
-        QVERIFY(dueDateEdit->isVisibleTo(&editor));
-        QVERIFY(recurrenceCombo->isVisibleTo(&editor));
-        QVERIFY(doneButton->isVisibleTo(&editor));
-        QVERIFY(attachmentList->isVisibleTo(&editor));
-        QVERIFY(addAttachmentButton->isVisibleTo(&editor));
-        QVERIFY(removeAttachmentButton->isVisibleTo(&editor));
-        QVERIFY(!delegateLabel->isVisibleTo(&editor));
-        QVERIFY(delegateEdit->isVisibleTo(&editor));
-    }
-
-    void shouldDisplayDelegateLabelOnlyWhenNeeded()
-    {
-        // GIVEN
-        Widgets::EditorView editor;
-        EditorModelStub model;
-        model.makeTaskAvailable();
-        model.setDelegateText(QStringLiteral("John Doe"));
-
-        auto delegateLabel = editor.findChild<QLabel*>(QStringLiteral("delegateLabel"));
-        QVERIFY(!delegateLabel->isVisibleTo(&editor));
-
-        // WHEN
-        editor.setModel(&model);
-
-        // THEN
-        auto expectedText = i18n("Delegated to: <b>%1</b>", model.property("delegateText").toString());
-        QVERIFY(delegateLabel->isVisibleTo(&editor));
-        QCOMPARE(delegateLabel->text(), expectedText);
-    }
-
-    void shouldBeEnabledOnlyWhenAnArtifactIsAvailable()
+    void shouldBeEnabledOnlyWhenAnTaskIsAvailable()
     {
         // GIVEN
         Widgets::EditorView editor;
@@ -326,14 +223,14 @@ private slots:
 
         // WHEN
         // like model.makeTaskAvailable() does:
-        Domain::Artifact::Ptr artifact(new Domain::Task);
-        model.setPropertyAndSignal("artifact", QVariant::fromValue(artifact));
+        Domain::Task::Ptr task(new Domain::Task);
+        model.setPropertyAndSignal("task", QVariant::fromValue(task));
 
         // THEN
         QVERIFY(editor.isEnabled());
 
         // WHEN
-        model.setPropertyAndSignal("artifact", QVariant::fromValue(Domain::Artifact::Ptr()));
+        model.setPropertyAndSignal("task", QVariant::fromValue(Domain::Task::Ptr()));
 
         // THEN
         QVERIFY(!editor.isEnabled());
@@ -342,7 +239,7 @@ private slots:
 
         // GIVEN
         EditorModelStub model2;
-        model2.setPropertyAndSignal("artifact", QVariant::fromValue(artifact));
+        model2.setPropertyAndSignal("task", QVariant::fromValue(task));
 
         // WHEN
         editor.setModel(&model2);
@@ -351,43 +248,16 @@ private slots:
         QVERIFY(editor.isEnabled());
     }
 
-    void shouldReactToHasTaskPropertiesChanged()
-    {
-        // GIVEN
-        Widgets::EditorView editor;
-        EditorModelStub model;
-        model.makeTaskAvailable();
-        editor.setModel(&model);
-
-        auto startDateEdit = editor.findChild<KPIM::KDateEdit*>(QStringLiteral("startDateEdit"));
-        QVERIFY(!startDateEdit->isVisibleTo(&editor));
-
-        auto dueDateEdit = editor.findChild<KPIM::KDateEdit*>(QStringLiteral("dueDateEdit"));
-        QVERIFY(!dueDateEdit->isVisibleTo(&editor));
-
-        auto doneButton = editor.findChild<QAbstractButton*>(QStringLiteral("doneButton"));
-        QVERIFY(!doneButton->isVisibleTo(&editor));
-
-        // WHEN
-        model.setPropertyAndSignal("hasTaskProperties", true);
-
-        // THEN
-        QVERIFY(startDateEdit->isVisibleTo(&editor));
-        QVERIFY(dueDateEdit->isVisibleTo(&editor));
-        QVERIFY(doneButton->isVisibleTo(&editor));
-    }
-
     void shouldDisplayModelProperties()
     {
         // GIVEN
         Widgets::EditorView editor;
         EditorModelStub model;
         model.makeTaskAvailable();
-        model.setProperty("hasTaskProperties", true);
         model.setProperty("title", "My title");
         model.setProperty("text", "\nMy text");
-        model.setProperty("startDate", QDateTime::currentDateTime());
-        model.setProperty("dueDate", QDateTime::currentDateTime().addDays(2));
+        model.setProperty("startDate", QDate::currentDate());
+        model.setProperty("dueDate", QDate::currentDate().addDays(2));
         model.setProperty("recurrence", QVariant::fromValue(Domain::Task::RecursWeekly));
         model.setProperty("done", true);
 
@@ -404,8 +274,8 @@ private slots:
         QCOMPARE(textEdit->toPlainText(), QString(model.property("title").toString()
                                                 + '\n'
                                                 + model.property("text").toString()));
-        QCOMPARE(startDateEdit->date(), model.property("startDate").toDateTime().date());
-        QCOMPARE(dueDateEdit->date(), model.property("dueDate").toDateTime().date());
+        QCOMPARE(startDateEdit->date(), model.property("startDate").toDate());
+        QCOMPARE(dueDateEdit->date(), model.property("dueDate").toDate());
         QCOMPARE(recurrenceCombo->currentData().value<Domain::Task::Recurrence>(), model.property("recurrence").value<Domain::Task::Recurrence>());
         QCOMPARE(doneButton->isChecked(), model.property("done").toBool());
     }
@@ -418,8 +288,8 @@ private slots:
         model.makeTaskAvailable();
         model.setProperty("title", "My title");
         model.setProperty("text", "\nMy text");
-        model.setProperty("startDate", QDateTime::currentDateTime());
-        model.setProperty("dueDate", QDateTime::currentDateTime().addDays(2));
+        model.setProperty("startDate", QDate::currentDate());
+        model.setProperty("dueDate", QDate::currentDate().addDays(2));
         model.setProperty("recurrence", QVariant::fromValue(Domain::Task::RecursWeekly));
         model.setProperty("done", true);
         editor.setModel(&model);
@@ -429,28 +299,23 @@ private slots:
         auto dueDateEdit = editor.findChild<KPIM::KDateEdit*>(QStringLiteral("dueDateEdit"));
         auto recurrenceCombo = editor.findChild<QComboBox*>(QStringLiteral("recurrenceCombo"));
         auto doneButton = editor.findChild<QAbstractButton*>(QStringLiteral("doneButton"));
-        auto delegateLabel = editor.findChild<QLabel*>(QStringLiteral("delegateLabel"));
-        auto delegateEdit = editor.findChild<QWidget*>(QStringLiteral("delegateEdit"));
-        model.setDelegateText(QStringLiteral("John Doe"));
         editor.setModel(&model);
 
         // WHEN
         editor.show();
-        QVERIFY(QTest::qWaitForWindowShown(&editor));
+        QVERIFY(QTest::qWaitForWindowExposed(&editor));
         editor.activateWindow();
         textEdit->setFocus();
         model.setTitle("New title");
         model.setText("New text");
         startDateEdit->setFocus();
-        model.setStartDate(QDateTime::currentDateTime().addDays(1));
+        model.setStartDate(QDate::currentDate().addDays(1));
         dueDateEdit->setFocus();
-        model.setDueDate(QDateTime::currentDateTime().addDays(3));
+        model.setDueDate(QDate::currentDate().addDays(3));
         recurrenceCombo->setFocus();
         model.setRecurrence(Domain::Task::RecursDaily);
         doneButton->setFocus();
         model.setDone(false);
-        delegateEdit->setFocus();
-        model.setDelegateText(QStringLiteral("John Smith"));
 
         // THEN (nothing changed)
         QCOMPARE(textEdit->toPlainText(), QStringLiteral("My title\n\nMy text"));
@@ -458,9 +323,6 @@ private slots:
         QCOMPARE(dueDateEdit->date(), QDate::currentDate().addDays(2));
         QCOMPARE(recurrenceCombo->currentData().value<Domain::Task::Recurrence>(), Domain::Task::RecursWeekly);
         QVERIFY(doneButton->isChecked());
-        auto expectedText = i18n("Delegated to: <b>%1</b>", QStringLiteral("John Doe"));
-        QCOMPARE(delegateLabel->text(), expectedText);
-
     }
 
     void shouldReactToTitleChanges()
@@ -471,8 +333,8 @@ private slots:
         model.makeTaskAvailable();
         model.setProperty("title", "My title");
         model.setProperty("text", "\nMy text");
-        model.setProperty("startDate", QDateTime::currentDateTime());
-        model.setProperty("dueDate", QDateTime::currentDateTime().addDays(2));
+        model.setProperty("startDate", QDate::currentDate());
+        model.setProperty("dueDate", QDate::currentDate().addDays(2));
         model.setProperty("done", true);
         editor.setModel(&model);
 
@@ -495,8 +357,8 @@ private slots:
         model.makeTaskAvailable();
         model.setProperty("title", "My title");
         model.setProperty("text", "\nMy text");
-        model.setProperty("startDate", QDateTime::currentDateTime());
-        model.setProperty("dueDate", QDateTime::currentDateTime().addDays(2));
+        model.setProperty("startDate", QDate::currentDate());
+        model.setProperty("dueDate", QDate::currentDate().addDays(2));
         model.setProperty("done", true);
         editor.setModel(&model);
 
@@ -550,8 +412,8 @@ private slots:
         model.makeTaskAvailable();
         model.setProperty("title", "My title");
         model.setProperty("text", "\nMy text");
-        model.setProperty("startDate", QDateTime::currentDateTime());
-        model.setProperty("dueDate", QDateTime::currentDateTime().addDays(2));
+        model.setProperty("startDate", QDate::currentDate());
+        model.setProperty("dueDate", QDate::currentDate().addDays(2));
         model.setProperty("done", false);
         editor.setModel(&model);
 
@@ -590,18 +452,18 @@ private slots:
         model.makeTaskAvailable();
         model.setProperty("title", "My title");
         model.setProperty("text", "\nMy text");
-        model.setProperty("startDate", QDateTime::currentDateTime());
-        model.setProperty("dueDate", QDateTime::currentDateTime().addDays(2));
+        model.setProperty("startDate", QDate::currentDate());
+        model.setProperty("dueDate", QDate::currentDate().addDays(2));
         model.setProperty("done", false);
         editor.setModel(&model);
 
         auto startDateEdit = editor.findChild<KPIM::KDateEdit*>(QStringLiteral("startDateEdit"));
 
         // WHEN
-        model.setPropertyAndSignal("startDate", QDateTime::currentDateTime().addDays(-2));
+        model.setPropertyAndSignal("startDate", QDate::currentDate().addDays(-2));
 
         // THEN
-        QCOMPARE(startDateEdit->date(), model.property("startDate").toDateTime().date());
+        QCOMPARE(startDateEdit->date(), model.property("startDate").toDate());
     }
 
     void shouldApplyStartDateEditChanges()
@@ -620,9 +482,8 @@ private slots:
         QTest::keyClick(startDateEdit, Qt::Key_Enter);
 
         // THEN
-        const QDateTime newStartDateTime = model.property("startDate").toDateTime();
-        QCOMPARE(newStartDateTime.date(), today);
-        QCOMPARE(newStartDateTime.timeSpec(), Qt::UTC);
+        const QDate newStartDate = model.property("startDate").toDate();
+        QCOMPARE(newStartDate, today);
     }
 
     void shouldReactToDueDateChanges()
@@ -632,18 +493,18 @@ private slots:
         EditorModelStub model;
         model.setProperty("title", "My title");
         model.setProperty("text", "\nMy text");
-        model.setProperty("startDate", QDateTime::currentDateTime());
-        model.setProperty("dueDate", QDateTime::currentDateTime().addDays(2));
+        model.setProperty("startDate", QDate::currentDate());
+        model.setProperty("dueDate", QDate::currentDate().addDays(2));
         model.setProperty("done", false);
         editor.setModel(&model);
 
         auto dueDateEdit = editor.findChild<KPIM::KDateEdit*>(QStringLiteral("dueDateEdit"));
 
         // WHEN
-        model.setPropertyAndSignal("dueDate", QDateTime::currentDateTime().addDays(-2));
+        model.setPropertyAndSignal("dueDate", QDate::currentDate().addDays(-2));
 
         // THEN
-        QCOMPARE(dueDateEdit->date(), model.property("dueDate").toDateTime().date());
+        QCOMPARE(dueDateEdit->date(), model.property("dueDate").toDate());
     }
 
     void shouldApplyDueDateEditChanges()
@@ -663,7 +524,7 @@ private slots:
         QTest::keyClick(dueDateEdit, Qt::Key_Enter);
 
         // THEN
-        QCOMPARE(model.property("dueDate").toDateTime().date(), today);
+        QCOMPARE(model.property("dueDate").toDate(), today);
     }
 
     void shouldApplyStartTodayChanges()
@@ -685,7 +546,7 @@ private slots:
 
         // THEN
         QCOMPARE(startDateEdit->currentText(), today.toString(QStringLiteral("dd/MM/yyyy")));
-        QCOMPARE(model.property("startDate").toDateTime().date(), today);
+        QCOMPARE(model.property("startDate").toDate(), today);
     }
 
     void shouldReactToRecurrenceChanges()
@@ -696,8 +557,8 @@ private slots:
         model.makeTaskAvailable();
         model.setProperty("title", "My title");
         model.setProperty("text", "\nMy text");
-        model.setProperty("startDate", QDateTime::currentDateTime());
-        model.setProperty("dueDate", QDateTime::currentDateTime().addDays(2));
+        model.setProperty("startDate", QDate::currentDate());
+        model.setProperty("dueDate", QDate::currentDate().addDays(2));
         model.setProperty("recurrence", QVariant::fromValue(Domain::Task::RecursWeekly));
         model.setProperty("done", false);
         editor.setModel(&model);
@@ -778,91 +639,6 @@ private slots:
         QCOMPARE(model.attachmentModel.data(model.attachmentModel.index(0, 0)).toString(),
                  QStringLiteral("/tmp/bar"));
     }
-
-    void shouldReactToDelegateTextChanges()
-    {
-        // GIVEN
-        Widgets::EditorView editor;
-        EditorModelStub model;
-        model.makeTaskAvailable();
-        model.setDelegateText(QStringLiteral("John Doe"));
-        editor.setModel(&model);
-
-        auto delegateLabel = editor.findChild<QLabel*>(QStringLiteral("delegateLabel"));
-
-        // WHEN
-        model.setDelegateText(QStringLiteral("John Smith"));
-
-        // THEN
-        auto expectedText = i18n("Delegated to: <b>%1</b>", model.property("delegateText").toString());
-        QCOMPARE(delegateLabel->text(), expectedText);
-    }
-
-    void shouldClearDelegateEditOnArtifactChanges()
-    {
-        // GIVEN
-        Widgets::EditorView editor;
-        EditorModelStub model;
-        model.makeTaskAvailable();
-        editor.setModel(&model);
-
-        auto delegateEdit = editor.findChild<KLineEdit*>(QStringLiteral("delegateEdit"));
-        delegateEdit->setText(QStringLiteral("Foo"));
-
-        // WHEN
-        model.makeTaskAvailable(); // simulates an artifact change
-
-        // THEN
-        QVERIFY(delegateEdit->text().isEmpty());
-    }
-
-    void shouldRequestDelegationOnInput_data()
-    {
-        QTest::addColumn<QString>("userInput");
-        QTest::addColumn<QString>("expectedName");
-        QTest::addColumn<QString>("expectedEmail");
-        QTest::addColumn<bool>("expectedCall");
-
-        QTest::newRow("nominal case") << "John Doe <john@doe.com>" << "John Doe" << "john@doe.com" << true;
-        QTest::newRow("nominal case") << "John Doe <j.doe@some.server.com>" << "John Doe" << "j.doe@some.server.com" << true;
-        QTest::newRow("only name") << "John Doe" << QString() << QString() << false;
-        QTest::newRow("only email") << "john@doe.com" << QString() << "john@doe.com" << true;
-        QTest::newRow("only email again") << "<john@doe.com>" << QString() << "john@doe.com" << true;
-        QTest::newRow("nonsense case") << "bleh" << QString() << QString() << false;
-    }
-
-    void shouldRequestDelegationOnInput()
-    {
-        // GIVEN
-        QFETCH(QString, userInput);
-        QFETCH(QString, expectedName);
-        QFETCH(QString, expectedEmail);
-        QFETCH(bool, expectedCall);
-
-        Widgets::EditorView editor;
-        EditorModelStub model;
-        model.makeTaskAvailable();
-        editor.setModel(&model);
-
-        auto delegateEdit = editor.findChild<KLineEdit*>(QStringLiteral("delegateEdit"));
-
-        // WHEN
-        QVERIFY(delegateEdit->isEnabled());
-        delegateEdit->setText(userInput);
-        QTest::keyClick(delegateEdit, Qt::Key_Enter);
-
-        // THEN
-        if (expectedCall) {
-            QCOMPARE(model.delegateNames.size(), 1);
-            QCOMPARE(model.delegateNames.first(), expectedName);
-            QCOMPARE(model.delegateEmails.size(), 1);
-            QCOMPARE(model.delegateEmails.first(), expectedEmail);
-            QVERIFY(delegateEdit->text().isEmpty());
-        } else {
-            QCOMPARE(model.delegateNames.size(), 0);
-            QCOMPARE(model.delegateEmails.size(), 0);
-        }
-    }
 };
 
 ZANSHIN_TEST_MAIN(EditorViewTest)
