@@ -33,23 +33,15 @@ public:
 
     MessageBoxStub() : m_called(false) {}
 
-    QMessageBox::Button askConfirmation(QWidget *, const QString &, const QString &) Q_DECL_OVERRIDE {
+    QMessageBox::Button askConfirmation(QWidget *, const QString &, const QString &) override {
         m_called = true;
         return QMessageBox::Yes;
     }
 
-    QString askTextInput(QWidget *, const QString &, const QString &) Q_DECL_OVERRIDE {
-        m_called = true;
-        return m_textInput;
-    }
-
     bool called() const { return m_called; }
 
-    void setTextInput(const QString &text) { m_textInput = text; }
-
 private:
     bool m_called;
-    QString m_textInput;
 };
 
 #endif
