@@ -24,6 +24,7 @@
 #include <testlib/qtest_gui_zanshin.h>
 
 #include <QAbstractItemModel>
+#include <QSortFilterProxyModel>
 #include <QAction>
 #include <QHeaderView>
 #include <QLayout>
@@ -42,7 +43,7 @@
 
 #include "domain/task.h"
 
-#include "presentation/artifactfilterproxymodel.h"
+#include "presentation/taskfilterproxymodel.h"
 #include "presentation/metatypes.h"
 #include "presentation/querytreemodelbase.h"
 
@@ -57,12 +58,20 @@ class PageModelStub : public QObject
     Q_OBJECT
     Q_PROPERTY(QAbstractItemModel* centralListModel READ centralListModel)
 public:
+    void setProxyModel(QAbstractProxyModel *proxy)
+    {
+        proxyModel = proxy;
+        proxyModel->setSourceModel(&itemModel);
+    }
+
     QAbstractItemModel *centralListModel()
     {
+        if (proxyModel)
+            return proxyModel;
         return &itemModel;
     }
 
-    QStandardItem *addStubItem(const QString &title, QStandardItem *parentItem = Q_NULLPTR)
+    QStandardItem *addStubItem(const QString &title, QStandardItem *parentItem = nullptr)
     {
         QStandardItem *item = new QStandardItem;
         item->setData(title, Qt::DisplayRole);
@@ -75,12 +84,12 @@ public:
         return item;
     }
 
-    Domain::Task::Ptr addTaskItem(const QString &title, QStandardItem *parentItem = Q_NULLPTR)
+    Domain::Task::Ptr addTaskItem(const QString &title, QStandardItem *parentItem = nullptr)
     {
         auto item = addStubItem(title, parentItem);
         auto task = Domain::Task::Ptr::create();
         task->setTitle(title);
-        item->setData(QVariant::fromValue<Domain::Artifact::Ptr>(task), Presentation::QueryTreeModelBase::ObjectRole);
+        item->setData(QVariant::fromValue(task), Presentation::QueryTreeModelBase::ObjectRole);
         return task;
     }
 
@@ -114,17 +123,18 @@ public:
     QList<QPersistentModelIndex> removedIndices;
     QList<QPersistentModelIndex> promotedIndices;
     QStandardItemModel itemModel;
+    QAbstractProxyModel *proxyModel = nullptr;
 };
 
 class RunningTaskModelStub : public Presentation::RunningTaskModelInterface
 {
     Q_OBJECT
 public:
-    Domain::Task::Ptr runningTask() const Q_DECL_OVERRIDE { return m_runningTask; }
-    void setRunningTask(const Domain::Task::Ptr &task) Q_DECL_OVERRIDE { m_runningTask = task; }
-    void taskDeleted(const Domain::Task::Ptr &task) Q_DECL_OVERRIDE { m_deletedTask = task; }
-    void stopTask() Q_DECL_OVERRIDE {}
-    void doneTask() Q_DECL_OVERRIDE {}
+    Domain::Task::Ptr runningTask() const override { return m_runningTask; }
+    void setRunningTask(const Domain::Task::Ptr &task) override { m_runningTask = task; }
+    void taskDeleted(const Domain::Task::Ptr &task) override { m_deletedTask = task; }
+    void stopTask() override {}
+    void doneTask() override {}
 private:
     Domain::Task::Ptr m_runningTask;
     Domain::Task::Ptr m_deletedTask;
@@ -175,7 +185,7 @@ private slots:
         QVERIFY(quickAddEdit);
         QVERIFY(quickAddEdit->isVisibleTo(&page));
         QVERIFY(quickAddEdit->text().isEmpty());
-        QCOMPARE(quickAddEdit->placeholderText(), i18n("Type and press enter to add an item"));
+        QCOMPARE(quickAddEdit->placeholderText(), i18n("Type and press enter to add a task"));
 
         auto addAction = page.findChild<QAction*>(QStringLiteral("addItemAction"));
         QVERIFY(addAction);
@@ -217,7 +227,7 @@ private slots:
         Widgets::PageView page;
         auto centralView = page.findChild<QTreeView*>(QStringLiteral("centralView"));
         QVERIFY(centralView);
-        auto proxyModel = qobject_cast<Presentation::ArtifactFilterProxyModel*>(centralView->model());
+        auto proxyModel = qobject_cast<Presentation::TaskFilterProxyModel*>(centralView->model());
         QVERIFY(proxyModel);
         QVERIFY(!proxyModel->sourceModel());
 
@@ -242,12 +252,12 @@ private slots:
 
         auto centralView = page.findChild<QTreeView*>(QStringLiteral("centralView"));
         QVERIFY(centralView);
-        auto proxyModel = qobject_cast<Presentation::ArtifactFilterProxyModel*>(centralView->model());
+        auto proxyModel = qobject_cast<Presentation::TaskFilterProxyModel*>(centralView->model());
         QVERIFY(proxyModel);
         QCOMPARE(proxyModel->sourceModel(), &model);
 
         // WHEN
-        page.setModel(Q_NULLPTR);
+        page.setModel(nullptr);
 
         // THEN
         QVERIFY(!page.model());
@@ -265,7 +275,7 @@ private slots:
         auto filterEdit = filter->findChild<QLineEdit*>();
         QVERIFY(filterEdit);
         page.show();
-        QVERIFY(QTest::qWaitForWindowShown(&page));
+        QVERIFY(QTest::qWaitForWindowExposed(&page));
 
         centralView->setFocus();
         QVERIFY(centralView->hasFocus());
@@ -323,7 +333,7 @@ private slots:
         auto filterEdit = filter->findChild<QLineEdit*>();
         QVERIFY(filterEdit);
         page.show();
-        QVERIFY(QTest::qWaitForWindowShown(&page));
+        QVERIFY(QTest::qWaitForWindowExposed(&page));
 
         centralView->setFocus();
         QVERIFY(centralView->hasFocus());
@@ -545,7 +555,7 @@ private slots:
 
         // Needed for shortcuts to work
         page.show();
-        QVERIFY(QTest::qWaitForWindowShown(&page));
+        QVERIFY(QTest::qWaitForWindowExposed(&page));
         QTest::qWait(100);
 
         // WHEN
@@ -556,7 +566,7 @@ private slots:
         QCOMPARE(stubPageModel.removedIndices.first(), index);
     }
 
-    void shouldNoteTryToDeleteIfThereIsNoSelection()
+    void shouldNotTryToDeleteIfThereIsNoSelection()
     {
         // GIVEN
         PageModelStub stubPageModel;
@@ -572,7 +582,7 @@ private slots:
 
         // Needed for shortcuts to work
         page.show();
-        QVERIFY(QTest::qWaitForWindowShown(&page));
+        QVERIFY(QTest::qWaitForWindowExposed(&page));
         QTest::qWait(100);
 
         // WHEN
@@ -604,7 +614,46 @@ private slots:
 
         // Needed for shortcuts to work
         page.show();
-        QVERIFY(QTest::qWaitForWindowShown(&page));
+        QVERIFY(QTest::qWaitForWindowExposed(&page));
+        QTest::qWait(100);
+
+        // WHEN
+        QTest::keyPress(centralView, Qt::Key_Delete);
+
+        // THEN
+        QVERIFY(msgbox->called());
+        QCOMPARE(stubPageModel.removedIndices.size(), 1);
+        QCOMPARE(stubPageModel.removedIndices.first(), index);
+    }
+
+    void shouldDisplayNotificationWhenHittingTheDeleteKeyOnAnItemWithHiddenChildren()
+    {
+        // GIVEN
+        PageModelStub stubPageModel;
+        Q_ASSERT(stubPageModel.property("centralListModel").canConvert<QAbstractItemModel*>());
+        stubPageModel.addStubItems(QStringList() << QStringLiteral("A") << QStringLiteral("B"));
+        QStandardItem *parentIndex = stubPageModel.itemModel.item(1, 0);
+        stubPageModel.addStubItem(QStringLiteral("C"), parentIndex);
+
+        QSortFilterProxyModel proxyModel;
+        stubPageModel.setProxyModel(&proxyModel);
+        proxyModel.setFilterFixedString("B");
+
+        QPersistentModelIndex index = stubPageModel.centralListModel()->index(0, 0);
+        QCOMPARE(index.data().toString(), QLatin1String("B"));
+        Widgets::PageView page;
+        page.setModel(&stubPageModel);
+        auto msgbox = MessageBoxStub::Ptr::create();
+        page.setMessageBoxInterface(msgbox);
+
+        QTreeView *centralView = page.findChild<QTreeView*>(QStringLiteral("centralView"));
+        centralView->selectionModel()->setCurrentIndex(index, QItemSelectionModel::ClearAndSelect);
+        QVERIFY(centralView->selectionModel()->currentIndex().isValid());
+        centralView->setFocus();
+
+        // Needed for shortcuts to work
+        page.show();
+        QVERIFY(QTest::qWaitForWindowExposed(&page));
         QTest::qWait(100);
 
         // WHEN
@@ -637,7 +686,7 @@ private slots:
 
         // Needed for shortcuts to work
         page.show();
-        QVERIFY(QTest::qWaitForWindowShown(&page));
+        QVERIFY(QTest::qWaitForWindowExposed(&page));
         QTest::qWait(100);
 
         // WHEN
@@ -761,7 +810,7 @@ private slots:
         // GIVEN
         Widgets::PageView page;
         page.show();
-        QVERIFY(QTest::qWaitForWindowShown(&page));
+        QVERIFY(QTest::qWaitForWindowExposed(&page));
         QTest::qWait(100);
 
         auto messageWidget = page.findChild<KMessageWidget*>(QStringLiteral("messageWidget"));
@@ -832,7 +881,7 @@ private slots:
 
         // THEN
         QCOMPARE(stubRunningTaskModel.property("runningTask").value<Domain::Task::Ptr>(), task1);
-        QCOMPARE(task1->startDate().date(), QDate::currentDate());
+        QCOMPARE(task1->startDate(), QDate::currentDate());
 
         // WHEN starting the second task
         QModelIndex index2 = stubPageModel.itemModel.index(1, 0);
@@ -841,7 +890,7 @@ private slots:
 
         // THEN
         QCOMPARE(stubRunningTaskModel.property("runningTask").value<Domain::Task::Ptr>(), task2);
-        QCOMPARE(task2->startDate().date(), QDate::currentDate());
+        QCOMPARE(task2->startDate(), QDate::currentDate());
     }
 };
 
